@@ -108,7 +108,7 @@ void SaveLensParameters(const wxString filename, HuginBase::Panorama* pano, unsi
     cfg.Write(wxT("Lens/crop/right"), cropRect.right());
     cfg.Write(wxT("Lens/crop/bottom"), cropRect.bottom());
 
-    if (image.hasEXIFread())
+    if (!image.getExifMake().empty() && !image.getExifModel().empty() && image.getExifFocalLength()>0)
     {
         // write exif data to ini file
         cfg.Write(wxT("EXIF/CameraMake"),  wxString(image.getExifMake().c_str(), wxConvLocal));
@@ -116,7 +116,7 @@ void SaveLensParameters(const wxString filename, HuginBase::Panorama* pano, unsi
         cfg.Write(wxT("EXIF/FocalLength"), image.getExifFocalLength());
         cfg.Write(wxT("EXIF/Aperture"), image.getExifAperture());
         cfg.Write(wxT("EXIF/ISO"), image.getExifISO());
-        cfg.Write(wxT("EXIF/CropFactor"), image.getExifCropFactor()); 
+        cfg.Write(wxT("EXIF/CropFactor"), image.getCropFactor()); 
         cfg.Write(wxT("EXIF/Distance"), image.getExifDistance()); 
     }
     cfg.Flush();
@@ -138,10 +138,10 @@ bool ApplyLensParameters(wxWindow * parent, PT::Panorama *pano, HuginBase::UIntS
         // Merge the lens parameters with the image variable map.
         HuginBase::VariableMapVector vars(images.size());
         size_t i=0;
-        for(HuginBase::UIntSet::const_iterator it=images.begin();it!=images.end();it++,i++)
+        for(HuginBase::UIntSet::const_iterator it=images.begin();it!=images.end();++it,++i)
         {
             vars[i]=pano->getImageVariables(*it);
-            for (HuginBase::LensVarMap::iterator it2 = lens.variables.begin(); it2 != lens.variables.end(); it2++)
+            for (HuginBase::LensVarMap::iterator it2 = lens.variables.begin(); it2 != lens.variables.end(); ++it2)
             {
                 if(it2->second.getName()=="EeV")
                 {
@@ -158,7 +158,7 @@ bool ApplyLensParameters(wxWindow * parent, PT::Panorama *pano, HuginBase::UIntS
         // update links
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> linkedVariables;
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> unlinkedVariables;
-        for (HuginBase::LensVarMap::iterator it = lens.variables.begin(); it != lens.variables.end(); it++)
+        for (HuginBase::LensVarMap::iterator it = lens.variables.begin(); it != lens.variables.end(); ++it)
         {
             if(it->second.getName()=="EeV")
             {
@@ -191,7 +191,7 @@ bool ApplyLensParameters(wxWindow * parent, PT::Panorama *pano, HuginBase::UIntS
         // Set the lens projection type.
         cmds.push_back(new PT::ChangeImageProjectionCmd(*pano, images, (HuginBase::SrcPanoImage::Projection) lens.getProjection()));
         // update crop factor
-        cmds.push_back(new PT::ChangeImageExifCropFactorCmd(*pano,images,lens.getCropFactor()));
+        cmds.push_back(new PT::ChangeImageCropFactorCmd(*pano,images,lens.getCropFactor()));
         // update the crop rect
         cmds.push_back(new PT::ChangeImageAutoCenterCropCmd(*pano,images,autoCenterCrop));
         if(cropped)
