@@ -108,7 +108,7 @@ void ImageVariableDialog::InitValues()
     BaseSrcPanoImage::ResponseType responseType= m_pano->getImage(*m_images.begin()).getResponseType();
     bool identical=true;
 
-    for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end() && identical;it++)
+    for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end() && identical;++it)
     {
         identical=(responseType==m_pano->getImage(*it).getResponseType());
     };
@@ -140,7 +140,7 @@ void ImageVariableDialog::InitValues()
         }
         double val=const_map_get(imgVarVector[*m_images.begin()],*varname).getValue();
         bool identical=true;
-        for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end() && identical;it++)
+        for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end() && identical;++it)
         {
             identical=(val==const_map_get(imgVarVector[*it],*varname).getValue());
         };
@@ -158,9 +158,13 @@ void ImageVariableDialog::SetGuiLevel(GuiLevel newLevel)
     XRCCTRL(*this, "image_variable_text_translation_x", wxStaticText)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_text_translation_y", wxStaticText)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_text_translation_z", wxStaticText)->Show(newLevel==GUI_EXPERT);
+    XRCCTRL(*this, "image_variable_text_translation_Tpy", wxStaticText)->Show(newLevel==GUI_EXPERT);
+    XRCCTRL(*this, "image_variable_text_translation_Tpp", wxStaticText)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_TrX", wxTextCtrl)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_TrY", wxTextCtrl)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_TrZ", wxTextCtrl)->Show(newLevel==GUI_EXPERT);
+    XRCCTRL(*this, "image_variable_Tpy", wxTextCtrl)->Show(newLevel==GUI_EXPERT);
+    XRCCTRL(*this, "image_variable_Tpp", wxTextCtrl)->Show(newLevel==GUI_EXPERT);
     // shear
     XRCCTRL(*this, "image_variable_text_shear", wxStaticText)->Show(newLevel==GUI_EXPERT);
     XRCCTRL(*this, "image_variable_text_shear_g", wxStaticText)->Show(newLevel==GUI_EXPERT);
@@ -224,7 +228,7 @@ bool ImageVariableDialog::ApplyNewVariables()
     if(sel!=wxNOT_FOUND)
     {
         std::vector<SrcPanoImage> SrcImgs;
-        for (UIntSet::const_iterator it=m_images.begin(); it!=m_images.end(); it++)
+        for (UIntSet::const_iterator it=m_images.begin(); it!=m_images.end(); ++it)
         {
             HuginBase::SrcPanoImage img=m_pano->getSrcImage(*it);
             img.setResponseType((SrcPanoImage::ResponseType)sel);
@@ -234,7 +238,7 @@ bool ImageVariableDialog::ApplyNewVariables()
     }
     if(varMap.size()>0)
     {
-        for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end();it++)
+        for(UIntSet::const_iterator it=m_images.begin();it!=m_images.end();++it)
         {
             commands.push_back(
                 new PT::UpdateImageVariablesCmd(*m_pano,*it,varMap)
@@ -281,7 +285,7 @@ void ImageVariableDialog::OnHelp(wxCommandEvent & e)
     };
 };
 
-const char *ImageVariableDialog::m_varNames[] = { "y", "p", "r", "TrX", "TrY", "TrZ", 
+const char *ImageVariableDialog::m_varNames[] = { "y", "p", "r", "TrX", "TrY", "TrZ", "Tpy", "Tpp", 
                                   "v", "a", "b", "c", "d", "e", "g", "t",
                                   "Eev", "Er", "Eb", 
                                   "Vb", "Vc", "Vd", "Vx", "Vy",
