@@ -161,6 +161,9 @@ void ImagesTreeCtrl::CreateColumns()
     ADDCOLUMN(wxT("X (TrX)"), "TrX", 60, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Camera translation X"))
     ADDCOLUMN(wxT("Y (TrY)"), "TrY", 60, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Camera translation Y"))
     ADDCOLUMN(wxT("Z (TrZ)"), "TrZ", 60, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Camera translation Z"))
+    ADDCOLUMN(_("Plane yaw"), "Tpy", 60, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Translation remap plane yaw"))
+    ADDCOLUMN(_("Plane pitch"), "Tpp", 60, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Translation remap plane pitch"))
+    ADDCOLUMN(_("Camera translation"), "cam_trans", 60, wxALIGN_LEFT, true, HuginBase::ImageVariableGroup::IVE_Yaw, _("Camera translation"))
 
     ADDCOLUMN(_("Lens type (f)"), "projection", 100, wxALIGN_LEFT, false, HuginBase::ImageVariableGroup::IVE_Filename, _("Lens type (rectilinear, fisheye, equirectangular, ...)"))
     ADDCOLUMN(_("Hfov (v)"), "v", 80, wxALIGN_RIGHT, true, HuginBase::ImageVariableGroup::IVE_HFOV, _("Horizontal field of view (v)"))
@@ -399,7 +402,9 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     const SrcPanoImage & img = m_pano->getImage(imgNr);
     wxFileName fn(wxString (img.getFilename().c_str(), HUGIN_CONV_FILENAME));
 
-    SetItemText(item, m_columnMap["imgNr"], wxString::Format(wxT("%d"), imgNr));
+    s << imgNr;
+    SetItemText(item, m_columnMap["imgNr"], s);
+    s.Clear();
     SetItemText(item, m_columnMap["filename"], fn.GetFullName() );
     SetItemText(item, m_columnMap["width"], wxString::Format(wxT("%d"), img.getSize().width()));
     SetItemText(item, m_columnMap["height"], wxString::Format(wxT("%d"), img.getSize().height()));
@@ -415,11 +420,13 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     }
     SetItemText(item, m_columnMap["anchor"], wxString(flags, wxConvLocal));
     std::vector<unsigned int> cps = m_pano->getCtrlPointsForImage(imgNr);
-    SetItemText(item, m_columnMap["cps"], wxString::Format(wxT("%d"), cps.size()));
+    s << cps.size();
+    SetItemText(item, m_columnMap["cps"], s);
+    s.Clear();
     unsigned int stackNumber = m_variable_groups->getStacks().getPartNumber(imgNr);
-    SetItemText(item, m_columnMap["stackNr"], wxString::Format(wxT("%d"), stackNumber));
+    SetItemText(item, m_columnMap["stackNr"], wxString::Format(wxT("%u"), stackNumber));
     unsigned int lensNr=m_variable_groups->getLenses().getPartNumber(imgNr);
-    SetItemText(item, m_columnMap["lensNr"], wxString::Format(wxT("%d"), lensNr));
+    SetItemText(item, m_columnMap["lensNr"], wxString::Format(wxT("%u"), lensNr));
 
     SetItemText(item, m_columnMap["maker"], wxString(img.getExifMake().c_str(), wxConvLocal));
     SetItemText(item, m_columnMap["model"], wxString(img.getExifModel().c_str(), wxConvLocal));
@@ -513,6 +520,9 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
         SetItemText(item, m_columnMap["TrX"], wxEmptyString);
         SetItemText(item, m_columnMap["TrY"], wxEmptyString);
         SetItemText(item, m_columnMap["TrZ"], wxEmptyString);
+        SetItemText(item, m_columnMap["Tpy"], wxEmptyString);
+        SetItemText(item, m_columnMap["Tpp"], wxEmptyString);
+        SetItemText(item, m_columnMap["cam_trans"], wxEmptyString);
     }
     else
     {
@@ -522,6 +532,15 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
         SetItemText(item, m_columnMap["TrX"], doubleTowxString(img.getX(), m_degDigits));
         SetItemText(item, m_columnMap["TrY"], doubleTowxString(img.getY(), m_degDigits));
         SetItemText(item, m_columnMap["TrZ"], doubleTowxString(img.getZ(), m_degDigits));
+        SetItemText(item, m_columnMap["Tpy"], doubleTowxString(img.getTranslationPlaneYaw(), m_degDigits));
+        SetItemText(item, m_columnMap["Tpp"], doubleTowxString(img.getTranslationPlanePitch(), m_degDigits));
+        wxString text=_("not active");
+        if(img.getX()!=0.0 || img.getY()!=0.0 || img.getZ()!=0.0 || img.getTranslationPlaneYaw()!=0.0 || img.getTranslationPlanePitch()!=0.0)
+        {
+            text=_("active");
+        };
+        text.Prepend(wxT(" "));
+        SetItemText(item, m_columnMap["cam_trans"], text);
     };
 
     if(m_groupMode==GROUP_LENS)
@@ -597,7 +616,7 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     }
     else
     {
-        SetItemText(item, m_columnMap["Er"], doubleTowxString(img.getWhiteBalanceRed(), m_pixelDigits));
+        SetItemText(item, m_columnMap["Er"], doubleTowxString(img.getWhiteBalanceRed(), m_pixelDigits+1));
     };
 
     if(m_groupMode==GROUP_LENS && img.WhiteBalanceBlueisLinked())
@@ -606,7 +625,7 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     }
     else
     {
-        SetItemText(item, m_columnMap["Eb"], doubleTowxString(img.getWhiteBalanceBlue(), m_pixelDigits));
+        SetItemText(item, m_columnMap["Eb"], doubleTowxString(img.getWhiteBalanceBlue(), m_pixelDigits+1));
     };
 
     if(m_groupMode==GROUP_LENS && img.RadialVigCorrCoeffisLinked())
@@ -660,16 +679,16 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
     switch(m_groupMode)
     {
         case GROUP_LENS:
-            SetItemText(item, 1, wxString::Format(_("Lens %d"),itemData->GetGroupNr()));
+            SetItemText(item, 1, wxString::Format(_("Lens %ld"),itemData->GetGroupNr()));
             break;
         case GROUP_STACK:
-            SetItemText(item, 1, wxString::Format(_("Stack %d"),itemData->GetGroupNr()));
+            SetItemText(item, 1, wxString::Format(_("Stack %ld"),itemData->GetGroupNr()));
             break;
         case GROUP_OUTPUTSTACK:
-            SetItemText(item, 1, wxString::Format(_("Output stack %d"),itemData->GetGroupNr()));
+            SetItemText(item, 1, wxString::Format(_("Output stack %ld"),itemData->GetGroupNr()));
             break;
         case GROUP_OUTPUTLAYERS:
-            SetItemText(item, 1, wxString::Format(_("Output exposure layer %d"),itemData->GetGroupNr()));
+            SetItemText(item, 1, wxString::Format(_("Output exposure layer %ld"),itemData->GetGroupNr()));
             break;
     };
     SetItemBold(item,1,true);
@@ -688,6 +707,15 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
             SetItemText(item, m_columnMap["TrX"], doubleTowxString(img.getX(), m_degDigits));
             SetItemText(item, m_columnMap["TrY"], doubleTowxString(img.getY(), m_degDigits));
             SetItemText(item, m_columnMap["TrZ"], doubleTowxString(img.getZ(), m_degDigits));
+            SetItemText(item, m_columnMap["Tpy"], doubleTowxString(img.getTranslationPlaneYaw(), m_degDigits));
+            SetItemText(item, m_columnMap["Tpp"], doubleTowxString(img.getTranslationPlanePitch(), m_degDigits));
+            wxString text=_("not active");
+            if(img.getX()!=0.0 || img.getY()!=0.0 || img.getZ()!=0.0 || img.getTranslationPlaneYaw()!=0.0 || img.getTranslationPlanePitch()!=0.0)
+            {
+                text=_("active");
+            };
+            text.Prepend(wxT(" "));
+            SetItemText(item, m_columnMap["cam_trans"], text);
         }
         else
         {
@@ -697,6 +725,9 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
             SetItemText(item, m_columnMap["TrX"], wxEmptyString);
             SetItemText(item, m_columnMap["TrY"], wxEmptyString);
             SetItemText(item, m_columnMap["TrZ"], wxEmptyString);
+            SetItemText(item, m_columnMap["Tpy"], wxEmptyString);
+            SetItemText(item, m_columnMap["Tpp"], wxEmptyString);
+            SetItemText(item, m_columnMap["cam_trans"], wxEmptyString);
         };
 
         if(m_groupMode==GROUP_LENS)
@@ -768,7 +799,7 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
 
         if(m_groupMode==GROUP_LENS && img.WhiteBalanceRedisLinked())
         {
-            SetItemText(item, m_columnMap["Er"], doubleTowxString(img.getWhiteBalanceRed(), m_pixelDigits));
+            SetItemText(item, m_columnMap["Er"], doubleTowxString(img.getWhiteBalanceRed(), m_pixelDigits+1));
         }
         else
         {
@@ -777,7 +808,7 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
 
         if(m_groupMode==GROUP_LENS && img.WhiteBalanceBlueisLinked())
         {
-            SetItemText(item, m_columnMap["Eb"], doubleTowxString(img.getWhiteBalanceBlue(), m_pixelDigits));
+            SetItemText(item, m_columnMap["Eb"], doubleTowxString(img.getWhiteBalanceBlue(), m_pixelDigits+1));
         }
         else
         {
@@ -884,7 +915,7 @@ void ImagesTreeCtrl::UpdateGroup(wxTreeItemId parent, const UIntSet imgs, UIntSe
             changed.erase(*it);
         };
         item=GetNextChild(parent, cookie);
-        it++;
+        ++it;
     };
 };
 
@@ -923,9 +954,20 @@ void ImagesTreeCtrl::UpdateOptimizerVariables()
                 if(set_contains(m_editableColumns,i))
                 {
                     bool opt=false;
-                    for(UIntSet::const_iterator it=imgNrs.begin(); it!=imgNrs.end() && !opt;it++)
+                    for(UIntSet::const_iterator it=imgNrs.begin(); it!=imgNrs.end() && !opt;++it)
                     {
-                        opt=set_contains(optVec[*it], m_columnVector[i]);
+                        if(m_columnVector[i]=="cam_trans")
+                        {
+                            opt=set_contains(optVec[*it], "TrX") &&
+                                set_contains(optVec[*it], "TrY") &&
+                                set_contains(optVec[*it], "TrZ") &&
+                                set_contains(optVec[*it], "Tpy") &&
+                                set_contains(optVec[*it], "Tpp");
+                        }
+                        else
+                        {
+                            opt=set_contains(optVec[*it], m_columnVector[i]);
+                        };
                     };
                     if(opt)
                     {
@@ -990,9 +1032,12 @@ void ImagesTreeCtrl::SetGuiLevel(GuiLevel newSetting)
 void ImagesTreeCtrl::SetOptimizerMode()
 {
     m_optimizerMode=true;
-    for(UIntSet::const_iterator it=m_editableColumns.begin(); it!=m_editableColumns.end(); it++)
+    for(UIntSet::const_iterator it=m_editableColumns.begin(); it!=m_editableColumns.end(); ++it)
     {
-        SetColumnEditable(*it,true);
+        if(m_columnVector[*it]!="cam_trans")
+        {
+            SetColumnEditable(*it,true);
+        };
     };
 };
 
@@ -1046,6 +1091,9 @@ void ImagesTreeCtrl::SetDisplayMode(DisplayMode newMode)
     SetColumnShown(m_columnMap["TrX"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
     SetColumnShown(m_columnMap["TrY"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
     SetColumnShown(m_columnMap["TrZ"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
+    SetColumnShown(m_columnMap["Tpy"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
+    SetColumnShown(m_columnMap["Tpp"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
+    SetColumnShown(m_columnMap["cam_trans"], m_displayMode==DISPLAY_POSITION && m_guiLevel==GUI_EXPERT);
 
     SetColumnShown(m_columnMap["projection"], m_displayMode==DISPLAY_LENS);
     SetColumnShown(m_columnMap["v"], m_displayMode==DISPLAY_LENS);
@@ -1129,7 +1177,10 @@ void ImagesTreeCtrl::OnContextMenu(wxTreeEvent & e)
                         menu.Append(ID_UNSELECT_LENS_STACK, _("Unselect all for current stack"));
                     };
                 };
-                menu.Append(ID_SELECT_ALL, _("Select all"));
+                if(m_columnVector[m_selectedColumn]!="cam_trans")
+                {
+                    menu.Append(ID_SELECT_ALL, _("Select all"));
+                };
                 menu.Append(ID_UNSELECT_ALL, _("Unselect all"));
                 menu.AppendSeparator();
             }
@@ -1140,7 +1191,10 @@ void ImagesTreeCtrl::OnContextMenu(wxTreeEvent & e)
     {
         if(m_optimizerMode && set_contains(m_editableColumns, e.GetInt()))
         {
-            menu.Append(ID_SELECT_ALL, _("Select all"));
+            if(m_columnVector[m_selectedColumn]!="cam_trans")
+            {
+                menu.Append(ID_SELECT_ALL, _("Select all"));
+            };
             menu.Append(ID_UNSELECT_ALL, _("Unselect all"));
             allowMenuExtension=false;
         }
@@ -1210,7 +1264,7 @@ void ImagesTreeCtrl::GenerateSubMenu(wxMenu* menu, PanoOperation::PanoOperationV
     UIntSet imgs=GetSelectedImages();
     for(size_t i=0; i<operations->size(); i++)
     {
-        if((*operations)[i]->IsEnabled(*m_pano, imgs))
+        if((*operations)[i]->IsEnabled(*m_pano, imgs, m_guiLevel))
         {
             menu->Append(id, (*operations)[i]->GetLabel());
             m_menuOperation[id]=(*operations)[i];
@@ -1246,6 +1300,8 @@ void ImagesTreeCtrl::UnLinkImageVariables(bool linked)
             variables.insert(HuginBase::ImageVariableGroup::IVE_X);
             variables.insert(HuginBase::ImageVariableGroup::IVE_Y);
             variables.insert(HuginBase::ImageVariableGroup::IVE_Z);
+            variables.insert(HuginBase::ImageVariableGroup::IVE_TranslationPlaneYaw);
+            variables.insert(HuginBase::ImageVariableGroup::IVE_TranslationPlanePitch);
         };
         if(m_groupMode==GROUP_LENS)
         {
@@ -1472,46 +1528,71 @@ void ImagesTreeCtrl::OnLeftDown(wxMouseEvent &e)
                         };
                         HuginBase::OptimizeVector optVec=m_pano->getOptimizeVector();
                         std::set<std::string> var;
-                        var.insert(m_columnVector[col]);
-                        if(m_columnVector[col]=="Vb" || m_columnVector[col]=="Vc" || m_columnVector[col]=="Vd")
+                        if(m_columnVector[col]=="cam_trans")
                         {
-                            var.insert("Vb");
-                            var.insert("Vc");
-                            var.insert("Vd");
-                        };
-                        if(m_columnVector[col]=="Vx" || m_columnVector[col]=="Vy")
+                            var.insert("TrX");
+                            var.insert("TrY");
+                            var.insert("TrZ");
+                            var.insert("Tpy");
+                            var.insert("Tpp");
+                        }
+                        else
                         {
-                            var.insert("Vx");
-                            var.insert("Vy");
+                            var.insert(m_columnVector[col]);
+                            if(m_columnVector[col]=="Tpy" || m_columnVector[col]=="Tpp")
+                            {
+                                var.insert("Tpy");
+                                var.insert("Tpp");
+                            };
+                            if(m_columnVector[col]=="Vb" || m_columnVector[col]=="Vc" || m_columnVector[col]=="Vd")
+                            {
+                                var.insert("Vb");
+                                var.insert("Vc");
+                                var.insert("Vd");
+                            };
+                            if(m_columnVector[col]=="Vx" || m_columnVector[col]=="Vy")
+                            {
+                                var.insert("Vx");
+                                var.insert("Vy");
+                            };
+                            if(m_columnVector[col]=="Ra" || m_columnVector[col]=="Rb" || m_columnVector[col]=="Rc" || 
+                               m_columnVector[col]=="Rd" || m_columnVector[col]=="Re")
+                            {
+                                var.insert("Ra");
+                                var.insert("Rb");
+                                var.insert("Rc");
+                                var.insert("Rd");
+                                var.insert("Re");
+                            };
                         };
-                        if(m_columnVector[col]=="Ra" || m_columnVector[col]=="Rb" || m_columnVector[col]=="Rc" || 
-                           m_columnVector[col]=="Rd" || m_columnVector[col]=="Re")
-                        {
-                            var.insert("Ra");
-                            var.insert("Rb");
-                            var.insert("Rc");
-                            var.insert("Rd");
-                            var.insert("Re");
-                        };
-                        for(std::set<std::string>::const_iterator varIt=var.begin(); varIt!=var.end(); varIt++)
+                        bool deactivate=false;
+                        for(std::set<std::string>::const_iterator varIt=var.begin(); varIt!=var.end(); ++varIt)
                         {
                             //search, if image variable is marked for optimise for at least one image of group
-                            bool deactivate=false;
-                            for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end() && !deactivate; imgIt++)
+                            for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end() && !deactivate; ++imgIt)
                             {
-                                deactivate=set_contains(optVec[*imgIt], *varIt);
+                                if(set_contains(optVec[*imgIt], *varIt))
+                                {
+                                    deactivate=true;
+                                };
                             };
-                            // now deactivate or activate the image variable for optimisation
-                            if(deactivate)
+                        };
+                        // now deactivate or activate the image variable for optimisation
+                        if(deactivate)
+                        {
+                            for(std::set<std::string>::const_iterator varIt=var.begin(); varIt!=var.end(); ++varIt)
                             {
-                                for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end(); imgIt++)
+                                for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end(); ++imgIt)
                                 {
                                     optVec[*imgIt].erase(*varIt);
                                 };
                             }
-                            else
+                        }
+                        else
+                        {
+                            for(std::set<std::string>::const_iterator varIt=var.begin(); varIt!=var.end(); ++varIt)
                             {
-                                for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end(); imgIt++)
+                                for(HuginBase::UIntSet::const_iterator imgIt=imgs.begin(); imgIt!=imgs.end(); ++imgIt)
                                 {
                                     optVec[*imgIt].insert(*varIt);
                                 };
@@ -1533,27 +1614,37 @@ void ImagesTreeCtrl::SelectAllParameters(bool select, bool allImages)
 {
     std::set<std::string> imgVars;
     std::string var=m_columnVector[m_selectedColumn];
-    imgVars.insert(var);
-    OptimizeVector optVec=m_pano->getOptimizeVector();
+    if(var=="cam_trans")
+    {
+        imgVars.insert("TrX");
+        imgVars.insert("TrY");
+        imgVars.insert("TrZ");
+        imgVars.insert("Tpy");
+        imgVars.insert("Tpp");
+    }
+    else
+    {
+        imgVars.insert(var);
+        if(var=="Vb" || var=="Vc" || var=="Vd")
+        {
+            imgVars.insert("Vb");
+            imgVars.insert("Vc");
+            imgVars.insert("Vd");
+        };
+        if(var=="Vx" || var=="Vy")
+        {
+            imgVars.insert("Vx");
+            imgVars.insert("Vy");
+        };
+        if(var=="Ra" || var=="Rb" || var=="Rc" || var=="Rd" || var=="Re")
+        {
+            imgVars.insert("Ra");
+            imgVars.insert("Rb");
+            imgVars.insert("Rc");
+            imgVars.insert("Rd");
+            imgVars.insert("Re");
+        };
 
-    if(var=="Vb" || var=="Vc" || var=="Vd")
-    {
-        imgVars.insert("Vb");
-        imgVars.insert("Vc");
-        imgVars.insert("Vd");
-    };
-    if(var=="Vx" || var=="Vy")
-    {
-        imgVars.insert("Vx");
-        imgVars.insert("Vy");
-    };
-    if(var=="Ra" || var=="Rb" || var=="Rc" || var=="Rd" || var=="Re")
-    {
-        imgVars.insert("Ra");
-        imgVars.insert("Rb");
-        imgVars.insert("Rc");
-        imgVars.insert("Rd");
-        imgVars.insert("Re");
     };
 
     UIntSet imgs;
@@ -1590,13 +1681,14 @@ void ImagesTreeCtrl::SelectAllParameters(bool select, bool allImages)
         };
     };
 
-    for(UIntSet::iterator img=imgs.begin(); img!=imgs.end(); img++)
+    OptimizeVector optVec=m_pano->getOptimizeVector();
+    for(UIntSet::iterator img=imgs.begin(); img!=imgs.end(); ++img)
     {
-        for(std::set<std::string>::const_iterator it=imgVars.begin(); it!=imgVars.end(); it++)
+        for(std::set<std::string>::const_iterator it=imgVars.begin(); it!=imgVars.end(); ++it)
         {
             if(select)
             {
-                if((*it=="y" || *it=="p" || *it=="r" || *it=="TrX" || *it=="TrY" || *it=="TrZ") && 
+                if((*it=="y" || *it=="p" || *it=="r" || *it=="TrX" || *it=="TrY" || *it=="TrZ" || *it=="Tpy" || *it=="Tpp") && 
                     *img==m_pano->getOptions().optimizeReferenceImage)
                 {
                     optVec[*img].erase(*it);
@@ -1769,7 +1861,7 @@ void ImagesTreeCtrl::OnEndEdit(wxTreeEvent &e)
 void ImagesTreeCtrl::OnExecuteOperation(wxCommandEvent & e)
 {
     PanoOperation::PanoOperation* op=m_menuOperation[e.GetId()];
-    PT::PanoCommand* cmd=op->GetCommand(this,*m_pano, GetSelectedImages());
+    PT::PanoCommand* cmd=op->GetCommand(this,*m_pano, GetSelectedImages(), m_guiLevel);
     if(cmd!=NULL)
     {
         GlobalCmdHist::getInstance().addCommand(cmd);
