@@ -48,14 +48,16 @@ wxString PanoOperation::GetLabel()
     return wxEmptyString;
 };
 
-bool PanoOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool PanoOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return true;
 };
 
-PT::PanoCommand* PanoOperation::GetCommand(wxWindow* parent, PT::Panorama& pano, HuginBase::UIntSet images)
+PT::PanoCommand* PanoOperation::GetCommand(wxWindow* parent, PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
-    if(IsEnabled(pano,images))
+    //remember gui level, only used by some PanoOperation's
+    m_guiLevel=guiLevel;
+    if(IsEnabled(pano, images, m_guiLevel))
     {
         return GetInternalCommand(parent,pano,images);
     }
@@ -65,12 +67,12 @@ PT::PanoCommand* PanoOperation::GetCommand(wxWindow* parent, PT::Panorama& pano,
     };
 };
 
-bool PanoSingleImageOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool PanoSingleImageOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return images.size()==1;
 };
 
-bool PanoMultiImageOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool PanoMultiImageOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return images.size()>0;
 };
@@ -308,7 +310,7 @@ PT::PanoCommand* AddImagesSeriesOperation::GetInternalCommand(wxWindow* parent,
     // For each globbed or loaded file,
     StringToPointerHash::iterator found;
     std::map<std::string, time_t> timeMap;
-    for (found = filenames.begin(); found != filenames.end(); found++)
+    for (found = filenames.begin(); found != filenames.end(); ++found)
     {
         wxString file = found->first;
         // Check the time if it's got a camera EXIF timestamp.
@@ -323,7 +325,7 @@ PT::PanoCommand* AddImagesSeriesOperation::GetInternalCommand(wxWindow* parent,
     //TODO: sorting the filenames keys by timestamp would be useful
     int maxtimediff = wxConfigBase::Get()->Read(wxT("CaptureTimeSpan"), HUGIN_CAPTURE_TIMESPAN);
     // For each timestamped file,
-    for (found = filenames.begin(); found != filenames.end(); found++)
+    for (found = filenames.begin(); found != filenames.end(); ++found)
     {
         wxString recruit = found->first;
         if (preloaded[recruit] == 1)
@@ -420,7 +422,7 @@ PT::PanoCommand* ChangeColorAnchorImageOperation::GetInternalCommand(wxWindow* p
     return new PT::SetPanoOptionsCmd(pano, opt);
 };
 
-bool NewLensOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool NewLensOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     if(pano.getNrOfImages()==0 || images.size()==0)
     {
@@ -443,7 +445,7 @@ PT::PanoCommand* NewLensOperation::GetInternalCommand(wxWindow* parent, PT::Pano
     return new PT::NewPartCmd(pano, images, HuginBase::StandardImageVariableGroups::getLensVariables());
 };
 
-bool ChangeLensOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool ChangeLensOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     if(pano.getNrOfImages()==0 || images.size()==0)
     {
@@ -520,7 +522,7 @@ PT::PanoCommand* LoadLensOperation::GetInternalCommand(wxWindow* parent, PT::Pan
     vigra::Size2D sizeImg0=pano.getImage(*(images.begin())).getSize();
     //check if all images have the same size
     bool differentImageSize=false;
-    for(UIntSet::const_iterator it=images.begin();it!=images.end() && !differentImageSize;it++)
+    for(UIntSet::const_iterator it=images.begin();it!=images.end() && !differentImageSize;++it)
     {
         differentImageSize=(pano.getImage(*it).getSize()!=sizeImg0);
     };
@@ -597,7 +599,7 @@ wxString RemoveControlPointsOperation::GetLabel()
     return _("Remove control points");
 };
 
-bool RemoveControlPointsOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool RemoveControlPointsOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return pano.getNrOfImages()>0 && pano.getNrOfCtrlPoints()>0;
 };
@@ -652,7 +654,7 @@ wxString CleanControlPointsOperation::GetLabel()
     return _("Clean control points");
 };
 
-bool CleanControlPointsOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool CleanControlPointsOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return pano.getNrOfCtrlPoints()>2;
 };
@@ -695,7 +697,7 @@ PT::PanoCommand* CleanControlPointsOperation::GetInternalCommand(wxWindow* paren
         UIntSet removedCP2=getCPoutsideLimit(newPano,2.0);
         if(removedCP2.size()>0)
         {
-            for(UIntSet::const_iterator it=removedCP2.begin();it!=removedCP2.end();it++)
+            for(UIntSet::const_iterator it=removedCP2.begin();it!=removedCP2.end();++it)
             {
                 removedCPs.insert(cpMap[*it]);
             };
@@ -793,6 +795,7 @@ ResetOperation::ResetOperation(ResetMode newResetMode)
 {
     m_resetMode=newResetMode;
     m_resetPos=(m_resetMode==RESET_POSITION);
+    m_resetTranslation=(m_resetMode==RESET_TRANSLATION);
     m_resetHFOV=(m_resetMode==RESET_LENS);
     m_resetLens=(m_resetMode==RESET_LENS);
     m_resetExposure=0;
@@ -801,7 +804,10 @@ ResetOperation::ResetOperation(ResetMode newResetMode)
         m_resetExposure=1;
     };
     m_resetVignetting=(m_resetMode==RESET_PHOTOMETRICS);
-    m_resetColor=(m_resetMode==RESET_PHOTOMETRICS);
+    if(m_resetMode==RESET_PHOTOMETRICS)
+    {
+        m_resetColor=1;
+    };
     m_resetCameraResponse=(m_resetMode==RESET_PHOTOMETRICS);
 };
 
@@ -817,6 +823,9 @@ wxString ResetOperation::GetLabel()
         case RESET_POSITION:
             return _("Reset positions");
             break;
+        case RESET_TRANSLATION:
+            return _("Reset translation parameters");
+            break;
         case RESET_LENS:
             return _("Reset lens parameters");
             break;
@@ -826,9 +835,16 @@ wxString ResetOperation::GetLabel()
     return wxEmptyString;
 };
 
-bool ResetOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool ResetOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
-    return pano.getNrOfImages()>0;
+    switch(m_resetMode)
+    {
+        case RESET_TRANSLATION:
+            return guiLevel>=GUI_EXPERT && pano.getNrOfImages()>0;
+            break;
+        default:
+            return pano.getNrOfImages()>0;
+    };
 };
 
 PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panorama& pano, HuginBase::UIntSet images)
@@ -845,7 +861,20 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
         fill_set(images,0,pano.getNrOfImages()-1);
     };
     // If we should unlink exposure value (to load it from EXIF)
-    bool needs_unlink = false;
+    bool needs_unlink_exposure = false;
+    bool needs_unlink_redbal = false;
+    bool needs_unlink_bluebal = false;
+    double redBalanceAnchor = pano.getImage(pano.getOptions().colorReferenceImage).getExifRedBalance();
+    double blueBalanceAnchor = pano.getImage(pano.getOptions().colorReferenceImage).getExifBlueBalance();
+    if(fabs(redBalanceAnchor)<1e-2)
+    {
+        redBalanceAnchor=1;
+    };
+    if(fabs(blueBalanceAnchor)<1e-2)
+    {
+        blueBalanceAnchor=1;
+    };
+
     VariableMapVector vars;
     for(UIntSet::const_iterator it = images.begin(); it != images.end(); it++)
     {
@@ -859,20 +888,25 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
             map_get(ImgVars,"TrX").setValue(0);
             map_get(ImgVars,"TrY").setValue(0);
             map_get(ImgVars,"TrZ").setValue(0);
+            map_get(ImgVars,"Tpy").setValue(0);
+            map_get(ImgVars,"Tpp").setValue(0);
         };
-        double cropFactor = 0;
-        double focalLength = 0;
-        double eV = 0;
-        SrcPanoImage srcImg = pano.getSrcImage(imgNr);
-        if(m_resetHFOV || m_resetExposure>0)
+        if(m_resetTranslation)
         {
-            srcImg.readEXIF(focalLength,cropFactor,eV,false,false);
+            map_get(ImgVars,"TrX").setValue(0);
+            map_get(ImgVars,"TrY").setValue(0);
+            map_get(ImgVars,"TrZ").setValue(0);
+            map_get(ImgVars,"Tpy").setValue(0);
+            map_get(ImgVars,"Tpp").setValue(0);
         };
+        SrcPanoImage srcImg = pano.getSrcImage(imgNr);
         if(m_resetHFOV)
         {
-            if(focalLength!=0&&cropFactor!=0)
+            double focalLength=srcImg.getExifFocalLength();
+            double cropFactor=srcImg.getExifCropFactor();
+            if(focalLength!=0 && cropFactor!=0)
             {
-                double newHFOV=calcHFOV(srcImg.getProjection(),focalLength,cropFactor,srcImg.getSize());
+                double newHFOV=HuginBase::SrcPanoImage::calcHFOV(srcImg.getProjection(), focalLength, cropFactor, srcImg.getSize());
                 if(newHFOV!=0)
                 {
                     map_get(ImgVars,"v").setValue(newHFOV);
@@ -893,16 +927,18 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
         {
             if(m_resetExposure==1)
             {
-                //reset to exif value
-                
-                if (pano.getImage(*it).ExposureValueisLinked())
+                if (pano.getImage(imgNr).ExposureValueisLinked())
                 {
                     /* Unlink exposure value variable so the EXIF values can be
                      * independant. */
-                    needs_unlink = true;
+                    needs_unlink_exposure = true;
                 }
+                //reset to exif value
+                double eV=srcImg.calcExifExposureValue();
                 if(eV!=0)
+                {
                     map_get(ImgVars,"Eev").setValue(eV);
+                }
             }
             else
             {
@@ -910,10 +946,49 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
                 map_get(ImgVars,"Eev").setValue(0);
             };
         };
-        if(m_resetColor)
+        if(m_resetColor>0)
         {
-            map_get(ImgVars,"Er").setValue(1);
-            map_get(ImgVars,"Eb").setValue(1);
+            if(m_resetColor==1)
+            {
+                if (pano.getImage(imgNr).WhiteBalanceRedisLinked())
+                {
+                    /* Unlink red balance variable so the EXIF values can be
+                     * independant. */
+                    needs_unlink_redbal = true;
+                }
+                if (pano.getImage(imgNr).WhiteBalanceBlueisLinked())
+                {
+                    /* Unlink red balance variable so the EXIF values can be
+                     * independant. */
+                    needs_unlink_bluebal = true;
+                }
+                double redBal=1;
+                double blueBal=1;
+                const SrcPanoImage& img=pano.getImage(imgNr);
+                const SrcPanoImage& anchor=pano.getImage(pano.getOptions().colorReferenceImage);
+                // use EXIF Red/BlueBalance data only if image and anchor image are from the same camera
+                if(img.getExifMake() == anchor.getExifMake() &&
+                    img.getExifModel() == anchor.getExifModel())
+                {
+                    redBal=fabs(img.getExifRedBalance()/redBalanceAnchor);
+                    if(redBal<1e-2)
+                    {
+                        redBal=1;
+                    };
+                    blueBal=fabs(img.getExifBlueBalance()/blueBalanceAnchor);
+                    if(blueBal<1e-2)
+                    {
+                        blueBal=1;
+                    };
+                };
+                map_get(ImgVars,"Er").setValue(redBal);
+                map_get(ImgVars,"Eb").setValue(blueBal);
+            }
+            else
+            {
+                map_get(ImgVars,"Er").setValue(1);
+                map_get(ImgVars,"Eb").setValue(1);
+            };
         };
         if(m_resetVignetting)
         {
@@ -935,7 +1010,7 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
         vars.push_back(ImgVars);
     };
     std::vector<PT::PanoCommand *> reset_commands;
-    if (needs_unlink)
+    if (needs_unlink_exposure)
     {
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> variables;
         variables.insert(HuginBase::ImageVariableGroup::IVE_ExposureValue);
@@ -949,6 +1024,34 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
                             HuginBase::StandardImageVariableGroups::getLensVariables())
                 );
     }
+    if (needs_unlink_redbal)
+    {
+        std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> variables;
+        variables.insert(HuginBase::ImageVariableGroup::IVE_WhiteBalanceRed);
+        
+        reset_commands.push_back(
+                new ChangePartImagesLinkingCmd(
+                            pano,
+                            images,
+                            variables,
+                            false,
+                            HuginBase::StandardImageVariableGroups::getLensVariables())
+                );
+    }
+    if (needs_unlink_bluebal)
+    {
+        std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> variables;
+        variables.insert(HuginBase::ImageVariableGroup::IVE_WhiteBalanceBlue);
+        
+        reset_commands.push_back(
+                new ChangePartImagesLinkingCmd(
+                            pano,
+                            images,
+                            variables,
+                            false,
+                            HuginBase::StandardImageVariableGroups::getLensVariables())
+                );
+    }
     reset_commands.push_back(
                             new PT::UpdateImagesVariablesCmd(pano, images, vars)
                                            );
@@ -962,7 +1065,7 @@ PT::PanoCommand* ResetOperation::GetInternalCommand(wxWindow* parent, PT::Panora
 
 bool ResetOperation::ShowDialog(wxWindow* parent)
 {
-    ResetDialog reset_dlg(parent);
+    ResetDialog reset_dlg(parent, m_guiLevel);
     bool checkGeometric;
     bool checkPhotometric;
     switch(m_resetMode)
@@ -986,6 +1089,7 @@ bool ResetOperation::ShowDialog(wxWindow* parent)
         if(checkGeometric)
         {
             m_resetPos=reset_dlg.GetResetPos();
+            m_resetTranslation=reset_dlg.GetResetTranslation();
             m_resetHFOV=reset_dlg.GetResetFOV();
             m_resetLens=reset_dlg.GetResetLens();
         };
@@ -1007,7 +1111,21 @@ bool ResetOperation::ShowDialog(wxWindow* parent)
                 m_resetExposure=0;
             };
             m_resetVignetting=reset_dlg.GetResetVignetting();
-            m_resetColor=reset_dlg.GetResetColor();
+            if(reset_dlg.GetResetColor())
+            {
+                if(reset_dlg.GetResetColorToExif())
+                {
+                    m_resetColor=1;
+                }
+                else
+                {
+                    m_resetColor=2;
+                };
+            }
+            else
+            {
+                m_resetColor=0;
+            };
             m_resetCameraResponse=reset_dlg.GetResetResponse();
         };
         return true;
@@ -1018,7 +1136,7 @@ bool ResetOperation::ShowDialog(wxWindow* parent)
     };
 };
 
-bool NewStackOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool NewStackOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     if(pano.getNrOfImages()==0 || images.size()==0)
     {
@@ -1041,7 +1159,7 @@ PT::PanoCommand* NewStackOperation::GetInternalCommand(wxWindow* parent, PT::Pan
     return new PT::NewPartCmd(pano, images, HuginBase::StandardImageVariableGroups::getStackVariables());
 };
 
-bool ChangeStackOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool ChangeStackOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     if(pano.getNrOfImages()==0 || images.size()==0)
     {
@@ -1080,7 +1198,7 @@ PT::PanoCommand* ChangeStackOperation::GetInternalCommand(wxWindow* parent, PT::
     };
 };
 
-bool AssignStacksOperation::IsEnabled(PT::Panorama& pano,HuginBase::UIntSet images)
+bool AssignStacksOperation::IsEnabled(PT::Panorama& pano, HuginBase::UIntSet images, GuiLevel guiLevel)
 {
     return pano.getNrOfImages()>1;
 };
@@ -1190,6 +1308,7 @@ void GeneratePanoOperationVector()
     PanoOpControlPoints.push_back(new CleanControlPointsOperation());
 
     PanoOpReset.push_back(new ResetOperation(ResetOperation::RESET_POSITION));
+    PanoOpReset.push_back(new ResetOperation(ResetOperation::RESET_TRANSLATION));
     PanoOpReset.push_back(new ResetOperation(ResetOperation::RESET_LENS));
     PanoOpReset.push_back(new ResetOperation(ResetOperation::RESET_PHOTOMETRICS));
     PanoOpReset.push_back(new ResetOperation(ResetOperation::RESET_DIALOG));
