@@ -27,6 +27,7 @@
 #include <config.h>
 #include "panoinc_WX.h"
 #include "wx/listbook.h"
+#include <wx/stdpaths.h> 
 #include "panoinc.h"
 
 #include "base_wx/wxPlatform.h"
@@ -62,6 +63,9 @@ BEGIN_EVENT_TABLE(PreferencesDialog, wxDialog)
     EVT_BUTTON(XRCID("prefs_defaults"), PreferencesDialog::OnRestoreDefaults)
     EVT_BUTTON(XRCID("prefs_enblend_select"), PreferencesDialog::OnEnblendExe)
     EVT_BUTTON(XRCID("prefs_enblend_enfuse_select"), PreferencesDialog::OnEnfuseExe)
+    EVT_BUTTON(XRCID("pref_exiftool_argfile_choose"), PreferencesDialog::OnExifArgfile)
+    EVT_BUTTON(XRCID("pref_exiftool_argfile_edit"), PreferencesDialog::OnExifArgfileEdit)
+    EVT_CHECKBOX(XRCID("pref_exiftool_metadata"), PreferencesDialog::OnExifTool)
     EVT_CHECKBOX(XRCID("prefs_ft_RotationSearch"), PreferencesDialog::OnRotationCheckBox)
     EVT_CHECKBOX(XRCID("prefs_enblend_Custom"), PreferencesDialog::OnCustomEnblend)
     EVT_CHECKBOX(XRCID("prefs_enblend_enfuseCustom"), PreferencesDialog::OnCustomEnfuse)
@@ -114,12 +118,14 @@ PreferencesDialog::PreferencesDialog(wxWindow* parent)
     lp = new long;
     *lp = wxLANGUAGE_BASQUE;
     lang_choice->Append(_("Basque"), lp);
+    /** outdated
     lp = new long;
     *lp = wxLANGUAGE_BULGARIAN;
     lang_choice->Append(_("Bulgarian"), lp);
     lp = new long;
     *lp = wxLANGUAGE_CATALAN;
     lang_choice->Append(_("Catalan"), lp);
+    */
     lp = new long;
     *lp = wxLANGUAGE_CHINESE_SIMPLIFIED;
     lang_choice->Append(_("Chinese (Simplified)"), lp);
@@ -153,9 +159,11 @@ PreferencesDialog::PreferencesDialog(wxWindow* parent)
     lp = new long;
     *lp = wxLANGUAGE_JAPANESE;
     lang_choice->Append(_("Japanese"), lp);
+    /** outdated
     lp = new long;
     *lp = wxLANGUAGE_KOREAN;
     lang_choice->Append(_("Korean"), lp);
+    */
     lp = new long;
     *lp = wxLANGUAGE_POLISH;
     lang_choice->Append(_("Polish"), lp);
@@ -168,18 +176,22 @@ PreferencesDialog::PreferencesDialog(wxWindow* parent)
     lp = new long;
     *lp = wxLANGUAGE_SLOVAK;
     lang_choice->Append(_("Slovak"), lp);
+    /** outdated
     lp = new long;
     *lp = wxLANGUAGE_SLOVENIAN;
     lang_choice->Append(_("Slovenian"), lp);
+    */
     lp = new long;
     *lp = wxLANGUAGE_SPANISH;
     lang_choice->Append(_("Spanish"), lp);
     lp = new long;
     *lp = wxLANGUAGE_SWEDISH;
     lang_choice->Append(_("Swedish"), lp);
+    /** outdated
     lp = new long;
     *lp = wxLANGUAGE_UKRAINIAN;
     lang_choice->Append(_("Ukrainian"), lp);
+    */
     lp = new long;
     *lp = wxLANGUAGE_FINNISH;
     lang_choice->Append(_("Finnish"), lp);
@@ -229,6 +241,11 @@ PreferencesDialog::PreferencesDialog(wxWindow* parent)
     cfg->Write(wxT("/Enfuse/Custom"), HUGIN_ENFUSE_EXE_CUSTOM);
 #endif
 
+#ifndef EXIFTOOL_GPANO_SUPPORT
+    //hide GPano tags checkbox if ExifTool is too old
+    XRCCTRL(*this, "pref_exiftool_gpano", wxCheckBox)->Hide();
+#endif
+
     RestoreFramePosition(this, wxT("PreferencesDialog"));
 }
 
@@ -316,6 +333,93 @@ void PreferencesDialog::OnCustomEnfuse(wxCommandEvent& e)
     XRCCTRL(*this, "prefs_enblend_enfuse_select", wxButton)->Enable(e.IsChecked());
 }
 
+void PreferencesDialog::OnExifArgfile(wxCommandEvent & e)
+{
+    wxFileDialog dlg(this,_("Select ExifTool argfile"),
+                     wxT(""), XRCCTRL(*this, "pref_exiftool_argfile", wxTextCtrl)->GetValue(), 
+                     _("ExifTool Argfiles (*.arg)|*.arg|All Files(*)|*"),
+                     wxFD_OPEN, wxDefaultPosition);
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        XRCCTRL(*this, "pref_exiftool_argfile", wxTextCtrl)->SetValue(
+            dlg.GetPath());
+    }
+}
+
+void CreateNewArgFile(const wxString& newFilename)
+{
+    wxTextFile defaultFile(MainFrame::Get()->GetDataPath()+wxT("hugin_exiftool_copy.arg"));
+    defaultFile.Open();
+    wxTextFile newFile(newFilename);
+    newFile.Create();
+    for(size_t i=0; i<defaultFile.GetLineCount(); ++i)
+    {
+        newFile.AddLine(defaultFile[i]);
+    };
+    newFile.Write();
+    defaultFile.Close();
+    newFile.Close();
+};
+
+void PreferencesDialog::OnExifArgfileEdit(wxCommandEvent & e)
+{
+    wxString filename=XRCCTRL(*this, "pref_exiftool_argfile", wxTextCtrl)->GetValue();
+    if(!filename.empty())
+    {
+        if(!wxFileName::FileExists(filename))
+        {
+            if( wxMessageBox(wxString::Format(_("File %s does not exist.\nShould the argfile be created with default tags?"),filename.c_str()),
+                  _("Exiftool argfile"), wxYES_NO  | wxICON_EXCLAMATION,this)!=wxYES)
+            {
+                return;
+            };
+            CreateNewArgFile(filename);
+        };
+    }
+    else
+    {
+        if( wxMessageBox(_("No file selected.\nShould an argfile be created with default tags?"),
+                _("Exiftool argfile"), wxYES_NO  | wxICON_EXCLAMATION,this)!=wxYES)
+        {
+            return;
+        };
+        wxFileDialog dlg(this,_("Select new ExifTool argfile"),
+            wxStandardPaths::Get().GetUserConfigDir(), wxT(""),
+                         _("ExifTool Argfiles (*.arg)|*.arg|All Files(*)|*"),
+                         wxFD_SAVE, wxDefaultPosition);
+        if (dlg.ShowModal() != wxID_OK)
+        {
+            return;
+        };
+        filename=dlg.GetPath();
+        CreateNewArgFile(filename);
+    };
+    XRCCTRL(*this, "pref_exiftool_argfile", wxTextCtrl)->SetValue(filename);
+    wxDialog * edit_dlg = wxXmlResource::Get()->LoadDialog(this, wxT("pref_edit_argfile"));
+    RestoreFramePosition(edit_dlg, wxT("EditArgfile"));
+    wxTextCtrl* argfileControl=XRCCTRL(*edit_dlg, "pref_edit_textcontrol", wxTextCtrl);
+    argfileControl->LoadFile(filename);
+    if(edit_dlg->ShowModal() == wxID_OK)
+    {
+        if(!argfileControl->SaveFile(filename))
+        {
+            wxMessageBox(wxString::Format(_("Could not save file \"%s\"."), filename.c_str()),
+                _("Error"), wxOK | wxICON_ERROR);
+        };
+        StoreFramePosition(edit_dlg, wxT("EditArgfile"));
+    };
+};
+
+void PreferencesDialog::OnExifTool(wxCommandEvent & e)
+{
+    bool copyMetadata=XRCCTRL(*this, "pref_exiftool_metadata", wxCheckBox)->GetValue();
+    XRCCTRL(*this, "pref_exiftool_argfile_label", wxStaticText)->Enable(copyMetadata);
+    XRCCTRL(*this, "pref_exiftool_argfile", wxTextCtrl)->Enable(copyMetadata);
+    XRCCTRL(*this, "pref_exiftool_argfile_choose", wxButton)->Enable(copyMetadata);
+    XRCCTRL(*this, "pref_exiftool_argfile_edit", wxButton)->Enable(copyMetadata);
+    XRCCTRL(*this, "pref_exiftool_gpano", wxCheckBox)->Enable(copyMetadata);
+};
+
 void PreferencesDialog::EnableRotationCtrls(bool enable)
 {
     XRCCTRL(*this, "prefs_ft_rot_panel", wxPanel)->Enable(enable);
@@ -392,6 +496,10 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         t = cfg->Read(wxT("CopyLogToClipboard"), 0l) == 1;
         MY_BOOL_VAL("prefs_copy_log", t);
 
+        // save makefile 
+        t = cfg->Read(wxT("SaveMakefile"), 0l) == 1;
+        MY_BOOL_VAL("prefs_makefile", t);
+
         t = cfg->Read(wxT("/GLPreviewFrame/ShowProjectionHints"), HUGIN_SHOW_PROJECTION_HINTS) == 1;
         MY_BOOL_VAL("pref_show_projection_hints", t)
     };
@@ -506,8 +614,13 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         MY_BOOL_VAL("pref_processor_verbose", t);
         UpdateProcessorControls();
 
-        t = cfg->Read(wxT("/output/useExiftool"), 1l) == 1;
+        t = cfg->Read(wxT("/output/useExiftool"), HUGIN_USE_EXIFTOOL) == 1;
         MY_BOOL_VAL("pref_exiftool_metadata", t);
+        MY_STR_VAL("pref_exiftool_argfile", cfg->Read(wxT("/output/CopyArgfile"), wxT("")));
+        t = cfg->Read(wxT("/output/writeGPano"), HUGIN_EXIFTOOL_CREATE_GPANO) == 1;
+        MY_BOOL_VAL("pref_exiftool_gpano", t);
+        wxCommandEvent dummy;
+        OnExifTool(dummy);
 
         int nThreads = cfg->Read(wxT("/output/NumberOfThreads"), 0l);
         MY_SPIN_VAL("prefs_output_NumberOfThreads", nThreads);
@@ -598,6 +711,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
             // smart undo
             cfg->Write(wxT("smartUndo"), HUGIN_SMART_UNDO);
             cfg->Write(wxT("CopyLogToClipboard"), 0l);
+            cfg->Write(wxT("SaveMakefile"), 0l);
             // projection hints
             cfg->Write(wxT("/GLPreviewFrame/ShowProjectionHints"), HUGIN_SHOW_PROJECTION_HINTS);
         }
@@ -655,7 +769,9 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
             cfg->Write(wxT("/Processor/parallel"), HUGIN_PROCESSOR_PARALLEL);
             cfg->Write(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE);
             cfg->Write(wxT("/Processor/verbose"), HUGIN_PROCESSOR_VERBOSE);
-            cfg->Write(wxT("/output/useExiftool"), 1l);
+            cfg->Write(wxT("/output/useExiftool"), HUGIN_USE_EXIFTOOL);
+            cfg->Write(wxT("/output/CopyArgfile"), wxT(""));
+            cfg->Write(wxT("/output/writeGPano"), HUGIN_EXIFTOOL_CREATE_GPANO);
             cfg->Write(wxT("/output/NumberOfThreads"), 0l);
 
         }
@@ -750,6 +866,7 @@ void PreferencesDialog::UpdateConfigData()
     // smart undo
     cfg->Write(wxT("smartUndo"), MY_G_BOOL_VAL("prefs_smart_undo"));
     cfg->Write(wxT("CopyLogToClipboard"), MY_G_BOOL_VAL("prefs_copy_log"));
+    cfg->Write(wxT("SaveMakefile"), MY_G_BOOL_VAL("prefs_makefile"));
     // show projections hints
     cfg->Write(wxT("/GLPreviewFrame/ShowProjectionHints"), MY_G_BOOL_VAL("pref_show_projection_hints"));
     // tempdir
@@ -786,6 +903,8 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Processor/verbose"), MY_G_BOOL_VAL("pref_processor_verbose"));
 
     cfg->Write(wxT("/output/useExiftool"), MY_G_BOOL_VAL("pref_exiftool_metadata"));
+    cfg->Write(wxT("/output/CopyArgfile"), MY_G_STR_VAL("pref_exiftool_argfile"));
+    cfg->Write(wxT("/output/writeGPano"), MY_G_BOOL_VAL("pref_exiftool_gpano"));
     cfg->Write(wxT("/output/NumberOfThreads"), MY_G_SPIN_VAL("prefs_output_NumberOfThreads"));
     /////
     /// STITCHING
