@@ -332,8 +332,12 @@ void FindPanoDialog::SearchInDir(wxString dirstring, const bool includeSubdir, c
                 ext.CmpNoCase(wxT("tif"))==0 || ext.CmpNoCase(wxT("tiff"))==0)
         {
             std::string filenamestr(file.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
-            SrcPanoImage* img=new SrcPanoImage(filenamestr);
-            if(img->hasEXIFread())
+            SrcPanoImage* img=new SrcPanoImage;
+            img->setFilename(filenamestr);
+            img->readEXIF();
+            img->applyEXIFValues();
+            if(!img->getExifMake().empty() && !img->getExifModel().empty() && 
+                img->getExifFocalLength()!=0 && img->getCropFactor()!=0)
             {
                 img->readProjectionFromDB();
                 if(loadDistortion)
@@ -426,7 +430,7 @@ PossiblePano::~PossiblePano()
 {
     if(m_images.size()>0)
     {
-        for(ImageSet::reverse_iterator it=m_images.rbegin(); it!=m_images.rend(); it++)
+        for(ImageSet::reverse_iterator it=m_images.rbegin(); it!=m_images.rend(); ++it)
         {
             delete (*it);
         }
@@ -470,7 +474,7 @@ double PossiblePano::GetMaxExposureDifference()
     }
     double minEv=1000;
     double maxEv=-1000;
-    for(ImageSet::const_iterator it=m_images.begin(); it!=m_images.end(); it++)
+    for(ImageSet::const_iterator it=m_images.begin(); it!=m_images.end(); ++it)
     {
         double ev=(*it)->getExposureValue();
         minEv=std::min(minEv,ev);
@@ -498,7 +502,7 @@ bool PossiblePano::IsStacked()
     }
     //now collect all unique exposure values
     std::set<int> evValues;
-    for(ImageSet::const_iterator it=m_images.begin(); it!=m_images.end(); it++)
+    for(ImageSet::const_iterator it=m_images.begin(); it!=m_images.end(); ++it)
     {
         //we multiply with 10 to don't get fooled by rounded double values
         evValues.insert(int((*it)->getExposureValue()*10));
@@ -523,7 +527,7 @@ bool PossiblePano::IsStacked()
     ImageSet::const_iterator it=m_images.begin();
     for(unsigned int i=0; i<evValues.size(); i++)
     {
-        it++;
+        ++it;
     };
     if(abs((*m_images.begin())->getExposureValue()-(*it)->getExposureValue())<0.1)
     {
@@ -551,7 +555,7 @@ const wxDateTime PossiblePano::GetDateTime(const SrcPanoImage* img)
 
 void PossiblePano::AddSrcPanoImage(HuginBase::SrcPanoImage* img)
 {
-    if(m_images.size()==0)
+    if(m_images.empty())
     {
         //fill all values from first image
         m_make=img->getExifMake();
@@ -675,7 +679,7 @@ bool PossiblePano::GetNewProjectFilename(NamingConvention nc,const wxString base
 
 wxString PossiblePano::GeneratePanorama(NamingConvention nc,bool createLinks)
 {
-    if(m_images.size()==0)
+    if(m_images.empty())
     {
         return wxEmptyString;
     };
@@ -689,7 +693,7 @@ wxString PossiblePano::GeneratePanorama(NamingConvention nc,bool createLinks)
     };
     //generate panorama
     HuginBase::Panorama pano;
-    for(ImageSet::iterator it=m_images.begin(); it!=m_images.end(); it++)
+    for(ImageSet::iterator it=m_images.begin(); it!=m_images.end(); ++it)
     {
         pano.addImage(*(*it));
     };
@@ -698,6 +702,16 @@ wxString PossiblePano::GeneratePanorama(NamingConvention nc,bool createLinks)
     HuginBase::ImageVariableGroup& lenses = variable_groups.getLenses();
     if(pano.getNrOfImages()>1)
     {
+        double redBalanceAnchor=pano.getImage(pano.getOptions().colorReferenceImage).getExifRedBalance();
+        double blueBalanceAnchor=pano.getImage(pano.getOptions().colorReferenceImage).getExifBlueBalance();
+        if(fabs(redBalanceAnchor)<1e-2)
+        {
+            redBalanceAnchor=1;
+        };
+        if(fabs(blueBalanceAnchor)<1e-2)
+        {
+            blueBalanceAnchor=1;
+        };
         for(unsigned int i=1; i<pano.getNrOfImages(); i++)
         {
             SrcPanoImage img=pano.getSrcImage(i);
@@ -707,8 +721,8 @@ wxString PossiblePano::GeneratePanorama(NamingConvention nc,bool createLinks)
             img.setExposureValue(ev);
             lenses.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_WhiteBalanceRed, i);
             lenses.unlinkVariableImage(HuginBase::ImageVariableGroup::IVE_WhiteBalanceBlue, i);
-            img.setWhiteBalanceRed(1);
-            img.setWhiteBalanceBlue(1);
+            img.setWhiteBalanceRed(img.getExifRedBalance()/redBalanceAnchor);
+            img.setWhiteBalanceBlue(img.getExifBlueBalance()/blueBalanceAnchor);
             pano.setSrcImage(i, img);
         };
     };
