@@ -69,6 +69,7 @@ static const makefile::string hdrRemappedExt(".exr");
 static const makefile::string ldrRemappedExt(".tif");
 static const makefile::string ldrRemappedMode("TIFF_m");
 static const makefile::string hdrRemappedMode("EXR_m");
+static const makefile::string requiredExiftoolsTags(" -WhitePoint -ColorSpace");
 
 PanoramaMakefilelibExport::PanoramaMakefilelibExport(PanoramaData & pano_,
             const UIntSet & images_,
@@ -80,11 +81,13 @@ PanoramaMakefilelibExport::PanoramaMakefilelibExport(PanoramaData & pano_,
             std::ostream & makefile_,
             const std::string& tmpDir_,
             const bool copyMetadata_,
+            const bool generateGPanoTags_,
             const int nrThreads_)
     : PanoramaAlgorithm(pano),
       pano(pano_), ptofile(ptofile_), outputPrefix(outputPrefix_),
       progs(progs_), includePath(includePath_), outputFiles(outputFiles_),
-      makefile(makefile_), tmpDir(tmpDir_), copyMetadata(copyMetadata_), nrThreads(nrThreads_)
+      makefile(makefile_), tmpDir(tmpDir_), copyMetadata(copyMetadata_), 
+      generateGPanoTags(generateGPanoTags_), nrThreads(nrThreads_)
 {
     images=getImagesinROI(pano_,images_);
     valuestream.imbue(makefile::GetMakefileLocale());
@@ -118,7 +121,7 @@ bool PanoramaMakefilelibExport::createItems()
 
 #ifdef _WINDOWS
     mgr.own_add(new Comment("Force using cmd.exe"));
-    mf::Variable* winshell = mgr.own(new mf::Variable("SHELL", getenv("ComSpec"), Makefile::NONE));
+    mf::Variable* winshell = mgr.own(new mf::Variable("SHELL", std::string(getenv("SystemRoot"))+"\\system32\\cmd.exe", Makefile::NONE));
     winshell->getDef().add();
 #endif
 
@@ -140,9 +143,8 @@ bool PanoramaMakefilelibExport::createItems()
 #else
     newVarDef(vrm, "RM", "rm");
 #endif
-
-    mf::Variable* vexiftool = mgr.own(new mf::Variable("EXIFTOOL", progs.exiftool));
-    vexiftool->getDef().add();
+    newVarDef(vexiftool, "EXIFTOOL", progs.exiftool);
+    newVarDef(vcheckpto, "CHECKPTO", progs.checkpto);
 
     if(nrThreads>0)
     {
@@ -300,8 +302,15 @@ bool PanoramaMakefilelibExport::createItems()
             (opts.getHFOV() == 360.0 ? " -w" : ""), Makefile::NONE);
 
     //----------
-    newVarDef(vexiftoolcopyargs,
-            "EXIFTOOL_COPY_ARGS", progs.exiftool_opts, Makefile::NONE);
+    newVarDef(vexiftoolcopyargfile,
+        "EXIFTOOL_COPY_ARGFILE", progs.exiftool_argfile, Makefile::SHELL);
+    // we are creating the argfile in the current directory, beside the images, here we have write access,
+    // the project file could be in a read only directory
+    std::string exiftoolinfoargfile=hugin_utils::stripPath(ptofile) + "_" + hugin_utils::stripPath(outputPrefix) + ".arg";
+    newVarDef(vexiftoolinfoargfile,
+        "EXIFTOOL_INFO_ARGFILE", exiftoolinfoargfile, Makefile::MAKE);
+    newVarDef(vexiftoolinfoargfileshell,
+        "EXIFTOOL_INFO_ARGFILE_SHELL", exiftoolinfoargfile, Makefile::SHELL);
 
     pano_projection_features proj;
     bool readProjectionName=panoProjectionFeaturesQuery(opts.getProjection(), &proj)!=0;
@@ -310,23 +319,6 @@ bool PanoramaMakefilelibExport::createItems()
     infostream.imbue(makefile::GetMakefileLocale());
     infostream << fixed;
     infostream.str("");
-#ifdef _WIN32
-    std::string linebreak("&\\#xd;&\\#xa;");
-    std::string quotechar("\"");
-#else
-    std::string linebreak("&\\#xa;");
-    std::string quotechar("'");
-#endif
-    infostream << quotechar << "-Software=Hugin " << DISPLAY_VERSION << quotechar << " ";
-    infostream << quotechar << "-UserComment<$${UserComment}" << linebreak;
-    if(readProjectionName)
-    {
-        infostream << "Projection: " << proj.name << " (" << opts.getProjection() << ")" << linebreak;
-    };
-    infostream << "FOV: " << setprecision(0) << opts.getHFOV() << " x " << setprecision(0) << opts.getVFOV() << linebreak;
-    infostream << "Ev: " << setprecision(2) << opts.outputExposureValue << quotechar << " -f";
-    newVarDef(vexiftoolinfoargs, "EXIFTOOL_INFO_ARGS", infostream.str(), Makefile::NONE);
-
     //----------
     // Panorama output
     mgr.own_add(new Comment("the output panorama"));
@@ -385,7 +377,7 @@ bool PanoramaMakefilelibExport::createItems()
     std::vector<std::string> remappedHDRImages;
     std::vector<std::string> remappedHDRgrayImages;
 
-    for (UIntSet::const_iterator it = images.begin(); it != images.end(); it++)
+    for (UIntSet::const_iterator it = images.begin(); it != images.end(); ++it)
     {
         std::ostringstream fn1, fn2, fn3;
         fn1 << outputPrefix << std::setfill('0') << std::setw(4) << *it << ldrRemappedExt;
@@ -447,6 +439,12 @@ bool PanoramaMakefilelibExport::createItems()
 
     std::vector<mf::Variable*> allprereqs, cleanprereqs;
 
+    // info argfile
+    if(copyMetadata)
+    {
+        cleanprereqs.push_back(vexiftoolinfoargfileshell);
+    };
+
     if(opts.outputLDRBlended)
     {
         allprereqs.push_back(vldrblended);
@@ -578,7 +576,7 @@ bool PanoramaMakefilelibExport::createItems()
     Rule* all = mgr.own(new Rule());
     all->addTarget("all");
     all->addPrereq(start);
-    for(std::vector<mf::Variable*>::const_iterator it = allprereqs.begin(); it != allprereqs.end(); it++)
+    for(std::vector<mf::Variable*>::const_iterator it = allprereqs.begin(); it != allprereqs.end(); ++it)
     {
         all->addPrereq((*it));
     }
@@ -592,7 +590,7 @@ bool PanoramaMakefilelibExport::createItems()
     echoInfo(*clean,"Remove temporary files");
     echoInfo(*clean,"===========================================================================");
     std::string vdefs;
-    for(std::vector<mf::Variable*>::const_iterator it = cleanprereqs.begin(); it != cleanprereqs.end(); it++)
+    for(std::vector<mf::Variable*>::const_iterator it = cleanprereqs.begin(); it != cleanprereqs.end(); ++it)
     {
         vdefs += (*it)->getRef() + " ";
     }
@@ -741,7 +739,7 @@ bool PanoramaMakefilelibExport::createItems()
     infostream.str("");
     infostream << images.size();
     echoInfo(*info,"Number of active images: "+infostream.str());
-    for(UIntSet::const_iterator it=images.begin();it!=images.end();it++)
+    for(UIntSet::const_iterator it=images.begin();it!=images.end();++it)
     {
         infostream.str("");
         const HuginBase::SrcPanoImage &img=pano.getImage(*it);
@@ -760,7 +758,7 @@ bool PanoramaMakefilelibExport::createItems()
         mgr.own_add(new Comment("Rules for ordinary TIFF_m and hdr output"));
         UIntSet::const_iterator it = images.begin();
         size_t i=0;
-        for(; it != images.end(); it++, i++)
+        for(; it != images.end(); ++it, ++i)
         {
             std::string source = Makefile::quote(pano.getImage(*it).getFilename(), Makefile::MAKE);
             std::ostringstream imgnr;
@@ -791,7 +789,7 @@ bool PanoramaMakefilelibExport::createItems()
         size_t j=0;
         for(i=0; i < exposures.size(); i++)
         {
-            for(UIntSet::const_iterator it = exposures[i].begin(); it != exposures[i].end(); it++, j++)
+            for(UIntSet::const_iterator it = exposures[i].begin(); it != exposures[i].end(); ++it, ++j)
             {
                 std::ostringstream expvalue, imgnr;
                 imgnr << *it;
@@ -836,7 +834,7 @@ bool PanoramaMakefilelibExport::createItems()
         if(copyMetadata)
         {
             ruleldr->addCommand("-" + vexiftool->getRef() + " -overwrite_original_in_place -TagsFromFile " +
-                    vinimage1shell->getRef() +" "+ vexiftoolcopyargs->getRef() +" "+ ldr_stacks_shell[i]->getRef());
+                    vinimage1shell->getRef() +requiredExiftoolsTags+" -@ "+ vexiftoolcopyargfile->getRef() +" "+ ldr_stacks_shell[i]->getRef());
         };
 
         Rule* rulehdr = mgr.own(new Rule()); rulehdr->add();
@@ -845,15 +843,35 @@ bool PanoramaMakefilelibExport::createItems()
         rulehdr->addCommand(vhdrmerge->getRef() +" "+ vhdrmergeopts->getRef() + " -o " +
                 hdr_stacks_shell[i]->getRef() +" -- "+ hdr_stacks_input_shell[i]->getRef());
     }
+    //-------------------- 
+    // info argfile
+    if(copyMetadata)
+    {
+        mgr.own(new Comment("Generate argfile for exiftool with all necessary information"));
+        Rule* ruleinfoargfile = mgr.own(new Rule()); 
+        ruleinfoargfile->add();
+        ruleinfoargfile->addTarget(vexiftoolinfoargfile);
+        ruleinfoargfile->addPrereq(vprojectfile);
+        std::string switches;
+#ifdef EXIFTOOL_GPANO_SUPPORT
+        if(!generateGPanoTags)
+        {
+            switches = " --no-gpano";
+        };
+#endif
+        switches += " --generate-argfile=";
+        ruleinfoargfile->addCommand(vcheckpto->getRef() + switches + vexiftoolinfoargfileshell->getRef() + " " + vprojectfileshell->getRef());
+    };
+
     //----------
     // Blend modes
     // these commands are often occuring
     const std::string enblendcmd = venblend->getRef() +" "+ venblendldrcomp->getRef() +" "+
             venblendopts->getRef() + " -o ";
     const std::string exifcmd = "-" + vexiftool->getRef() + " -overwrite_original_in_place -TagsFromFile " +
-            vinimage1shell->getRef() +" "+ vexiftoolcopyargs->getRef() +' ';
-    const std::string exifcmd2 = "-" + vexiftool->getRef() + " -E -overwrite_original_in_place -TagsFromFile " +
-            vinimage1shell->getRef() +" "+ vexiftoolcopyargs->getRef() + " " + vexiftoolinfoargs->getRef() + " ";
+            vinimage1shell->getRef() +requiredExiftoolsTags+" -@ "+ vexiftoolcopyargfile->getRef() +' ';
+    const std::string exifcmd2 = "-" + vexiftool->getRef() + " -overwrite_original_in_place -TagsFromFile " +
+            vinimage1shell->getRef() +requiredExiftoolsTags+" -@ "+ vexiftoolcopyargfile->getRef() + " -@ " + vexiftoolinfoargfileshell->getRef() + " ";
     const std::string ptrollercmd = vPTroller->getRef() + " -o ";
 
     if(opts.blendMode == PanoramaOptions::ENBLEND_BLEND)
@@ -866,6 +884,7 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addCommand(enblendcmd + vldrblendedshell->getRef() +" -- "+ vldrlayersshell->getRef());
         if(copyMetadata)
         {
+            rule->addPrereq(vexiftoolinfoargfile);
             rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
         };
 
@@ -891,6 +910,7 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addCommand(enblendcmd + vldrstackedblendedshell->getRef() +" -- "+ vldrstacksshell->getRef());
         if(copyMetadata)
         {
+            rule->addPrereq(vexiftoolinfoargfile);
             rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
         };
 
@@ -902,6 +922,7 @@ bool PanoramaMakefilelibExport::createItems()
                 vldrexposurelayersfusedshell->getRef() +" -- "+ vldrexposurelayersshell->getRef());
         if(copyMetadata)
         {
+            rule->addPrereq(vexiftoolinfoargfile);
             rule->addCommand(exifcmd2 + vldrexposurelayersfusedshell->getRef());
         };
 
@@ -949,6 +970,7 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addCommand(ptrollercmd + vldrblendedshell->getRef() +" "+ vldrlayersshell->getRef());
         if(copyMetadata)
         {
+            rule->addPrereq(vexiftoolinfoargfile);
             rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
         };
 
@@ -973,6 +995,7 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addCommand(ptrollercmd + vldrstackedblendedshell->getRef() +" "+ vldrstacksshell->getRef());
         if(copyMetadata)
         {
+            rule->addPrereq(vexiftoolinfoargfile);
             rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
         };
 
@@ -987,9 +1010,9 @@ bool PanoramaMakefilelibExport::createItems()
 }
 
 
-void PanoramaMakefilelibExport::createstacks(const std::vector<UIntSet> stackdata,
-        const std::string stkname,
-        const std::string filenamecenter, const std::string inputfilenamecenter, const std::string filenameext,
+void PanoramaMakefilelibExport::createstacks(const std::vector<UIntSet>& stackdata,
+        const std::string& stkname,
+        const std::string& filenamecenter, const std::string& inputfilenamecenter, const std::string& filenameext,
         std::vector<mf::Variable*>& stacks,
         std::vector<mf::Variable*>& stacks_shell,
         std::vector<mf::Variable*>& stacks_input,
@@ -1008,7 +1031,7 @@ void PanoramaMakefilelibExport::createstacks(const std::vector<UIntSet> stackdat
         allfiles.push_back(filename.str());
 
         std::vector<std::string> inputs;
-        for (UIntSet::const_iterator it = stackdata[i].begin(); it != stackdata[i].end(); it++)
+        for (UIntSet::const_iterator it = stackdata[i].begin(); it != stackdata[i].end(); ++it)
         {
             std::ostringstream fns;
             fns << outputPrefix << inputfilenamecenter << std::setfill('0') << std::setw(4) << *it << filenameext;
@@ -1038,7 +1061,7 @@ void PanoramaMakefilelibExport::createstacks(const std::vector<UIntSet> stackdat
     std::vector<mf::Variable*>::const_iterator it, it2;
     it = stacks.begin();
     it2 = stacks_shell.begin();
-    for(; it != stacks.end() && it2 != stacks_shell.end(); it++, it2++)
+    for(; it != stacks.end() && it2 != stacks_shell.end(); ++it, ++it2)
     {
         stackrefs += (*it)->getRef() + " ";
         stackrefsshell += (*it2)->getRef() + " ";
@@ -1049,9 +1072,9 @@ void PanoramaMakefilelibExport::createstacks(const std::vector<UIntSet> stackdat
     vstacksshell->getDef().add();
 
 }
-void PanoramaMakefilelibExport::createexposure(const std::vector<UIntSet> stackdata,
-        const std::string stkname,
-        const std::string filenamecenter, const std::string inputfilenamecenter, const std::string filenameext,
+void PanoramaMakefilelibExport::createexposure(const std::vector<UIntSet>& stackdata,
+        const std::string& stkname,
+        const std::string& filenamecenter, const std::string& inputfilenamecenter, const std::string& filenameext,
         std::vector<mf::Variable*>& stacks,
         std::vector<mf::Variable*>& stacks_shell,
         std::vector<mf::Variable*>& stacks_input,
@@ -1076,7 +1099,7 @@ void PanoramaMakefilelibExport::createexposure(const std::vector<UIntSet> stackd
 
         std::vector<std::string> inputs, inputspt;
         double exposure = 0;
-        for (UIntSet::const_iterator it = stackdata[i].begin(); it != stackdata[i].end(); it++)
+        for (UIntSet::const_iterator it = stackdata[i].begin(); it != stackdata[i].end(); ++it)
         {
             std::ostringstream fns, fnpt;
             fns << outputPrefix << inputfilenamecenter << std::setfill('0') << std::setw(4) << *it << filenameext;
@@ -1122,7 +1145,7 @@ void PanoramaMakefilelibExport::createexposure(const std::vector<UIntSet> stackd
     std::vector<mf::Variable*>::const_iterator it, it2;
     it = stacks.begin();
     it2 = stacks_shell.begin();
-    for(; it != stacks.end() && it2 != stacks_shell.end(); it++, it2++)
+    for(; it != stacks.end() && it2 != stacks_shell.end(); ++it, ++it2)
     {
         stackrefs += (*it)->getRef() + " ";
         stackrefsshell += (*it2)->getRef() + " ";
@@ -1292,12 +1315,35 @@ void PanoramaMakefilelibExport::printSystemInfo(Rule& inforule)
 #endif
 };
 
+/** returns the default argfile for exiftool */
+std::string GetDefaultArgfile()
+{
+    std::string default_argfile=hugin_utils::GetDataDir();
+    default_argfile.append("hugin_exiftool_copy.arg");
+    return default_argfile;
+};
+
+void CheckExifToolArgfile(HuginBase::PanoramaMakefilelibExport::PTPrograms& progs)
+{
+    if(!progs.exiftool_argfile.empty())
+    {
+        if(!FileExists(progs.exiftool_argfile))
+        {
+            progs.exiftool_argfile=GetDefaultArgfile();
+        };
+    }
+    else
+    {
+        progs.exiftool_argfile=GetDefaultArgfile();
+    };
+};
+
 void printstacks(const std::vector<UIntSet>& stackdata)
 {
     std::cout << "printstacks: \n";
-    for(std::vector<UIntSet>::const_iterator itv = stackdata.begin(); itv != stackdata.end(); itv++)
+    for(std::vector<UIntSet>::const_iterator itv = stackdata.begin(); itv != stackdata.end(); ++itv)
     {
-        for(UIntSet::const_iterator itu = itv->begin(); itu != itv->end(); itu++)
+        for(UIntSet::const_iterator itu = itv->begin(); itu != itv->end(); ++itu)
         {
             std::cout << *itu << " ";
         }
