@@ -22,6 +22,7 @@
  */
 
 #include "LensDB.h"
+#define BOOST_FILESYSTEM_VERSION 3
 #include <boost/filesystem.hpp>
 #include <iostream>
 #include <hugin_utils/stl_utils.h>
@@ -36,14 +37,6 @@ namespace HuginBase
 namespace LensDB
 {
 
-#if BOOST_FILESYSTEM_VERSION < 3
-typedef boost::filesystem::basic_path<std::string, boost::filesystem::path_traits> basic_path;
-#define GETPATHSTRING(x) x
-#else
-typedef boost::filesystem::path basic_path;
-#define GETPATHSTRING(x) (x).string()
-#endif
-
 LensDB* LensDB::m_instance=NULL;
 
 LensDB::LensDB()
@@ -163,20 +156,20 @@ bool LensDB::LoadFilesInDir(std::string path)
     if(m_db==NULL)
         return false;
     lfError e=LF_NO_ERROR;
-    basic_path p(path);
+    boost::filesystem::path p(path);
     try
     {
         if(exists(p))
         {
             if (is_directory(p))
             {
-                typedef std::vector<basic_path> fl_vec;
+                typedef std::vector<boost::filesystem::path> fl_vec;
                 fl_vec filelist;
                 std::copy(boost::filesystem::directory_iterator(p), boost::filesystem::directory_iterator(), std::back_inserter(filelist));
-                for(fl_vec::const_iterator it=filelist.begin();it!=filelist.end();it++)
+                for(fl_vec::const_iterator it=filelist.begin();it!=filelist.end();++it)
                 {
-                    basic_path file=*it;
-                    if(GETPATHSTRING(file.extension())==std::string(".xml"))
+                    boost::filesystem::path file=*it;
+                    if(file.extension().string()==std::string(".xml"))
                     {
                         lfError e2=m_db->Load(file.string().c_str());
                         if(e==LF_NO_ERROR && e2!=LF_NO_ERROR)
@@ -639,6 +632,20 @@ bool LensDB::GetDistortion(double focal, std::vector<double> &distortion)
     };
 };
 
+// returns a valid subject disance
+// lensfun expects the following
+// undef (0) distance treated as 1000
+// infinity distance also treated as 1000
+double enforceValidSubjectDistance(double inputDistance)
+{
+    double validDistance=fabs(inputDistance);
+    if(validDistance<0.01)
+    {
+        return 1000;
+    };
+    return std::min(validDistance, 1000.0);
+};
+
 bool LensDB::GetVignetting(double focal, double aperture, double distance, std::vector<double> &vignetting)
 {
     vignetting.clear();
@@ -652,7 +659,7 @@ bool LensDB::GetVignetting(double focal, double aperture, double distance, std::
         checkedAperture=aperture;
     };
     lfLensCalibVignetting calibVig;
-    if(m_lenses[0]->InterpolateVignetting(focal,checkedAperture,distance,calibVig))
+    if(m_lenses[0]->InterpolateVignetting(focal, checkedAperture, enforceValidSubjectDistance(distance), calibVig))
     {
         switch(calibVig.Model)
         {
@@ -695,7 +702,7 @@ bool LensDB::SaveCameraCrop(std::string filename, std::string maker, std::string
         return false;
     };
     // load if file exists already
-    basic_path p(filename);
+    boost::filesystem::path p(filename);
     if(boost::filesystem::exists(p))
     {
         if(boost::filesystem::is_regular_file(p))
@@ -816,7 +823,7 @@ int LensDB::BeginSaveLens(std::string filename, std::string maker, std::string l
         return 1;
     };
     // load if file exists already
-    basic_path p(filename);
+    boost::filesystem::path p(filename);
     m_lensFilename=p.string();
     if(boost::filesystem::exists(p))
     {
@@ -914,8 +921,18 @@ int LensDB::BeginSaveLens(std::string filename, std::string maker, std::string l
         lf_lens_copy(m_updatedLenses[i],allLenses[i]);
         if(updateLens)
         {
-            if(strcmp(m_updatedLenses[i]->Model,oldLenses[0]->Model)==0 && 
-               strcmp(m_updatedLenses[i]->Maker,oldLenses[0]->Maker)==0)
+            bool sameMaker=true;
+            // maker string can be empty, so compare strings with special case for empty strings
+            if(m_updatedLenses[i]->Maker && oldLenses[0]->Maker)
+            {
+                sameMaker=strcmp(m_updatedLenses[i]->Maker,oldLenses[0]->Maker)==0;
+            }
+            else
+            {
+                sameMaker=(m_updatedLenses[i]->Maker==NULL && oldLenses[0]->Maker==NULL);
+            };
+            // for model we can make it easier because Model is always given/forced
+            if(strcmp(m_updatedLenses[i]->Model,oldLenses[0]->Model)==0 && sameMaker)
             {
                 bool compareMounts=false;
                 if(oldLenses[0]->Mounts)
@@ -1096,13 +1113,14 @@ void LensDB::SaveVignetting(double focal, double aperture, double distance, std:
             return;
         };
         int index=-1;
+        double validDistance=enforceValidSubjectDistance(distance);
         if(m_currentLens->CalibVignetting)
         {
             for(int i=0;m_currentLens->CalibVignetting[i];i++)
             {
                 if(abs(m_currentLens->CalibVignetting[i]->Focal-focal)<0.05 &&
                    abs(m_currentLens->CalibVignetting[i]->Aperture-aperture)<0.05 &&
-                   abs(m_currentLens->CalibVignetting[i]->Distance-distance)<0.05)
+                   abs(m_currentLens->CalibVignetting[i]->Distance-validDistance)<0.05)
                 {
                     index=i;
                     break;
@@ -1116,7 +1134,7 @@ void LensDB::SaveVignetting(double focal, double aperture, double distance, std:
         lfLensCalibVignetting lcv;
         lcv.Focal=focal;
         lcv.Aperture=aperture;
-        lcv.Distance=distance;
+        lcv.Distance=validDistance;
         lcv.Model=LF_VIGNETTING_MODEL_PA;
         lcv.Terms[0]=vignetting[1];
         lcv.Terms[1]=vignetting[2];
@@ -1184,7 +1202,6 @@ bool LensDB::IsNewMount(std::string newMount)
         return false;
     };
     //check, if mount is already in new file
-    mount=NULL;
     mount=m_newDB->FindMount(newMount.c_str());
     if(mount)
     {
@@ -1296,7 +1313,7 @@ std::string LensDBList::GetLensName(size_t index) const
     };
 };
 
-void LensDBList::SetCameraModelMaker(const std::string camMaker, const std::string camModel)
+void LensDBList::SetCameraModelMaker(const std::string& camMaker, const std::string& camModel)
 {
     m_camMaker=camMaker;
     m_camModel=camModel;
