@@ -147,7 +147,7 @@ void ScaleLines(Lines& lines,const double scale)
     };
 };
 
-HuginBase::CPVector GetControlPoints(const SingleLine line,const unsigned int imgNr, const unsigned int lineNr,const unsigned int numberOfCtrlPoints)
+HuginBase::CPVector GetControlPoints(const SingleLine& line,const unsigned int imgNr, const unsigned int lineNr,const unsigned int numberOfCtrlPoints)
 {
     HuginBase::CPVector cpv;
     double interval = (line.line.size()-1)/(1.0*numberOfCtrlPoints);
@@ -227,7 +227,7 @@ VerticalLineVector FilterLines(Lines lines,double roll)
     VerticalLineVector vertLines;
     if(lines.size()>0)
     {
-        for(Lines::const_iterator it=lines.begin(); it!=lines.end(); it++)
+        for(Lines::const_iterator it=lines.begin(); it!=lines.end(); ++it)
         {
             if((*it).status==valid_line && (*it).line.size()>2)
             {
@@ -316,9 +316,9 @@ HuginBase::CPVector _getVerticalLines(const HuginBase::Panorama& pano,const unsi
     if(focalLength==0)
     {
         focalLength=HuginBase::SrcPanoImage::calcFocalLength(
-            srcImage.getProjection(),srcImage.getHFOV(),srcImage.getExifCropFactor(),srcImage.getSize());
+            srcImage.getProjection(),srcImage.getHFOV(),srcImage.getCropFactor(),srcImage.getSize());
     };
-    Lines foundLines=findLines(*edge,0.05,focalLength,srcImage.getExifCropFactor());
+    Lines foundLines=findLines(*edge,0.05,focalLength,srcImage.getCropFactor());
     //filter results
     VerticalLineVector filteredLines=FilterLines(foundLines,roll);
     //create control points
