@@ -32,10 +32,8 @@
 
 #include <iostream>
 #include <vector>
-//#include <vigra/diff2d.hxx>
-//#include <vigra/imageinfo.hxx>
 #include <panotools/PanoToolsInterface.h>
-
+#include <panodata/PTScriptParsing.h>
 
 namespace HuginBase {
 
@@ -104,7 +102,7 @@ bool MaskPolygon::isPositive() const
            (m_maskType==Mask_Stack_positive);
 };
 
-void MaskPolygon::setMaskPolygon(const VectorPolygon newMask)
+void MaskPolygon::setMaskPolygon(const VectorPolygon& newMask)
 {
     m_polygon=newMask;
     calcBoundingBox();
@@ -294,7 +292,7 @@ FDiff2D clip_getIntersection(const FDiff2D p, const FDiff2D q, const vigra::Rect
     return FDiff2D(xnew,ynew);
 };
 
-VectorPolygon clip_onPlane(const VectorPolygon polygon, const vigra::Rect2D r, const clipSide side)
+VectorPolygon clip_onPlane(const VectorPolygon& polygon, const vigra::Rect2D r, const clipSide side)
 {
     if(polygon.size()<3)
     {
@@ -380,9 +378,9 @@ std::vector<FDiff2D> clip_getIntersectionCircle(const FDiff2D p, const FDiff2D s
             t.insert(t2);
         };
     };
-    if(t.size()>0)
+    if(!t.empty())
     {
-        for(std::set<double>::const_iterator it=t.begin();it!=t.end();it++)
+        for(std::set<double>::const_iterator it=t.begin();it!=t.end();++it)
         {
             intersections.push_back(p+slope*(*it));
         };
@@ -602,7 +600,7 @@ const bool MaskPolygon::operator==(const MaskPolygon &otherPoly) const
     return ((m_maskType == otherPoly.getMaskType()) && (m_polygon == otherPoly.getMaskPolygon()));
 };
 
-bool MaskPolygon::parsePolygonString(const std::string polygonStr)
+bool MaskPolygon::parsePolygonString(const std::string& polygonStr)
 {
     m_polygon.clear();
     if(polygonStr.length()==0)
@@ -633,4 +631,55 @@ void MaskPolygon::printPolygonLine(std::ostream &o, const unsigned int newImgNr)
     o<<"\""<<std::endl;
 };
 
+void LoadMaskFromStream(std::istream& stream,vigra::Size2D& imageSize, MaskPolygonVector &newMasks, size_t imgNr)
+{
+    while (stream.good()) 
+    {
+        std::string line;
+        std::getline(stream,line);
+        switch (line[0]) 
+        {
+            case '#':
+            {
+                unsigned int w;
+                if (PTScriptParsing::getIntParam(w, line, "w"))
+                    imageSize.setWidth(w);
+                unsigned int h;
+                if (PTScriptParsing::getIntParam(h, line, "h"))
+                    imageSize.setHeight(h);
+                break;
+            }
+            case 'k':
+            {
+                HuginBase::MaskPolygon newPolygon;
+                //Ignore image number set in mask
+                newPolygon.setImgNr(imgNr);
+                unsigned int param;
+                if (PTScriptParsing::getIntParam(param,line,"t"))
+                {
+                    newPolygon.setMaskType((HuginBase::MaskPolygon::MaskType)param);
+                }
+                std::string format;
+                if (PTScriptParsing::getPTParam(format,line,"p"))
+                {
+                    if(newPolygon.parsePolygonString(format)) {
+                        newMasks.push_back(newPolygon);
+                    } 
+                }
+                break;
+            }
+            default:
+            {
+                break;
+            }
+        }
+    }
+};
+
+void SaveMaskToStream(std::ostream& stream, vigra::Size2D imageSize, MaskPolygon &maskToWrite, size_t imgNr)
+{
+    stream << "# w" << imageSize.width() << " h" << imageSize.height() << std::endl;
+    maskToWrite.printPolygonLine(stream, imgNr);
+};
+
 } // namespace
