@@ -70,9 +70,6 @@ extern "C" {
 
     }
 
-//
-//#include "PT/PanoImage.h"
-
 #include <hugin_shared.h>
 #include <vigra_ext/Interpolators.h>
 
@@ -109,7 +106,8 @@ class IMPEX PanoramaOptions
             BIPLANE = 17,
             TRIPLANE = 18,
             GENERAL_PANINI = 19,
-            THOBY_PROJECTION = 20
+            THOBY_PROJECTION = 20,
+            HAMMER_AITOFF = 21,
         };
 
         /** PTStitcher acceleration */
