@@ -53,6 +53,8 @@ using vigra::NumericTraits;
 namespace vigra_ext
 {
 
+IMPEX void SetGPUDebugMessages(const bool doPrint);
+
 bool IMPEX transformImageGPUIntern(const std::string& coordXformGLSL,
                              const std::string& interpolatorGLSL,
                              const int interpolatorSize,
@@ -285,7 +287,13 @@ void transformImageAlphaGPUIntern(vigra::triple<SrcImageIterator, SrcImageIterat
 
     std::ostringstream coordXformOss;
     coordXformOss << std::setprecision(20) << std::showpoint;
-    transform.emitGLSL(coordXformOss);
+    if(!transform.emitGLSL(coordXformOss))
+    {
+        std::cerr << "nona: Found unsupported transformation in stack." << std::endl
+             << "      This geometric transformation is not supported by GPU." << std::endl
+             << "      Remove -g switch and try with CPU transformation." << std::endl;
+        exit(1);
+    };
 
     std::ostringstream interpolatorOss;
     interpolatorOss << std::setprecision(20) << std::showpoint;
