@@ -31,6 +31,7 @@
 #include "zthread/PoolExecutor.h"
 #include "Utils.h"
 #include "Tracer.h"
+#include "hugin_base/hugin_utils/platform.h"
 
 #include <algorithms/nona/ComputeImageROI.h>
 #include <nona/RemappedPanoImage.h>
@@ -46,16 +47,10 @@
 #include "ImageImport.h"
 
 #ifdef _WINDOWS
-#include <windows.h>
 #include <direct.h>
 #else
 #include <unistd.h>
-#endif
-#ifdef __APPLE__
 #include <hugin_config.h>
-#include <mach-o/dyld.h>	/* _NSGetExecutablePath */
-#include <limits.h>		/* PATH_MAX */
-#include <libgen.h>		/* dirname */
 #endif
 
 #ifndef srandom
@@ -112,7 +107,7 @@ PanoDetector::PanoDetector() :
     _writeAllKeyPoints(false), _verbose(1),
     _sieve1Width(10), _sieve1Height(10), _sieve1Size(100),
     _kdTreeSearchSteps(200), _kdTreeSecondDistance(0.25), _ransacIters(1000), _ransacDistanceThres(50),
-    _sieve2Width(5), _sieve2Height(5),_sieve2Size(1), _test(false), _cores(utils::getCPUCount()),
+    _sieve2Width(5), _sieve2Height(5),_sieve2Size(1), _test(false), _cores(hugin_utils::getCPUCount()),
     _minimumMatches(6), _linearMatchLen(1), _downscale(true), _cache(false), _cleanup(false),
     _keypath(""), _outputFile("default.pto"), _outputGiven(false), _celeste(false), _celesteThreshold(0.5), _celesteRadius(20), 
     _matchingStrategy(ALLPAIRS)
@@ -380,41 +375,7 @@ bool PanoDetector::LoadSVMModel()
     ifstream test(model_file.c_str());
     if (!test.good())
     {
-#if _WINDOWS
-        char buffer[MAX_PATH];//always use MAX_PATH for filepaths
-        GetModuleFileNameA(NULL,buffer,sizeof(buffer));
-        string working_path=(buffer);
-        string install_path_model="";
-        //remove filename
-        std::string::size_type pos=working_path.rfind("\\");
-        if(pos!=std::string::npos)
-        {
-            working_path.erase(pos);
-            //remove last dir: should be bin
-            pos=working_path.rfind("\\");
-            if(pos!=std::string::npos)
-            {
-                working_path.erase(pos);
-                //append path delimiter and path
-                working_path.append("\\share\\hugin\\data\\");
-                install_path_model=working_path;
-            }
-        }
-#elif defined MAC_SELF_CONTAINED_BUNDLE
-        //string install_path_model = ("./xrc/");
-        char path[PATH_MAX + 1];
-        uint32_t size = sizeof(path);
-        string install_path_model("");
-        if (_NSGetExecutablePath(path, &size) == 0)
-        {
-            //install_path_model=path;
-            install_path_model=dirname(path);
-            install_path_model.append("/xrc/");
-            cout << "Detected path " << install_path_model << endl << endl;
-        }
-#else
-        string install_path_model = (INSTALL_DATA_DIR);
-#endif
+        string install_path_model=hugin_utils::GetDataDir();
         install_path_model.append(model_file);
         ifstream test2(install_path_model.c_str());
         if (!test2.good())
@@ -844,8 +805,7 @@ bool PanoDetector::loadProject()
         // Specify if the image has an associated keypoint file
 
         aImgData._keyfilename = getKeyfilenameFor(_keypath,aImgData._name);
-        ifstream keyfile(aImgData._keyfilename.c_str());
-        aImgData._hasakeyfile = keyfile.good();
+        aImgData._hasakeyfile = hugin_utils::FileExists(aImgData._keyfilename);
         if(aImgData._hasakeyfile)
         {
             imgWithKeyfile++;
