@@ -46,9 +46,8 @@
 #include <nona/Stitcher.h>
 #include <algorithms/basic/CalculateOptimalROI.h>
 
-#ifdef WIN32
- #include <getopt.h>
-#else
+#include <getopt.h>
+#ifndef WIN32
  #include <unistd.h>
 #endif
 
@@ -79,10 +78,15 @@ static void usage(const char * name)
          << " Modifiers" << std::endl
          << "  -v        Verbose, print progress messages.  Repeat for higher verbosity" << std::endl
          << "  -e        Assume input images are full frame fish eye (default: rectilinear)" << std::endl
-         << "  -t num    Remove all control points with an error higher than num pixels (default: 3)" << std::endl
-         << "  -f HFOV   approximate horizontal field of view of input images, use if EXIF info not complete" << std::endl
+         << "  -t num    Remove all control points with an error higher than num pixels" << std::endl
+         << "             (default: 3)" << std::endl
+         << "  --corr=num  Correlation threshold for identifing control points" << std::endl
+         << "               (default: 0.9)" << std::endl
+         << "  -f HFOV   approximate horizontal field of view of input images," << std::endl
+         << "             use if EXIF info not complete" << std::endl
          << "  -m        Optimize field of view for all images, except for first." << std::endl
-         << "             Useful for aligning focus stacks with slightly different magnification." << std::endl
+         << "             Useful for aligning focus stacks with slightly" << std::endl
+         << "             different magnification." << std::endl
          << "  -d        Optimize radial distortion for all images, except for first." << std::endl
          << "  -i        Optimize image center shift for all images, except for first." << std::endl
          << "  -x        Optimize X coordinate of the camera position." << std::endl
@@ -93,71 +97,21 @@ static void usage(const char * name)
          << "  -A        Align stereo window - assumes -S." << std::endl
          << "  -P        Align stereo window with pop-out effect - assumes -S." << std::endl
          << "  -C        Auto crop the image to the area covered by all images." << std::endl
-         << "  -c num    number of control points (per grid) to create between adjacent images (default: 8)" << std::endl
+         << "  -c num    number of control points (per grid) to create" << std::endl
+         << "             between adjacent images (default: 8)" << std::endl
          << "  -l        Assume linear input files" << std::endl
-	 << "  -s scale  Scale down image by 2^scale (default: 1 [2x downsampling])" << std::endl
-	 << "  -g gsize  Break image into a rectangular grid (gsize x gsize) and attempt to find " << std::endl 
-	 << "             num control points in each section (default: 5 [5x5 grid] )" << std::endl
+         << "  -s scale  Scale down image by 2^scale (default: 1 [2x downsampling])" << std::endl
+         << "  -g gsize  Break image into a rectangular grid (gsize x gsize) and attempt" << std::endl
+         << "             to find num control points in each section" << std::endl 
+         << "             (default: 5 [5x5 grid] )" << std::endl
+         << "  --threads=NUM  Use NUM threads" << std::endl
+         << "  --gpu     Use GPU for remapping" << std::endl
          << "  -h        Display help (this text)" << std::endl
          << std::endl;
 }
 
-
-#if 0
-template <class VALUETYPE>
-class InterestPointSelector
-{
-public:
-
-        /** the functor's argument type
-        */
-    typedef VALUETYPE argument_type;
-
-        /** the functor's result type
-        */
-    typedef VALUETYPE result_type;
-
-        /** \deprecated use argument_type
-        */
-    typedef VALUETYPE value_type;
-
-
-    InterestPointSelector(int nrPoints)
-    {
-        minResponse = 0;
-        nPoints = nrPoints;
-    }
-
-    void operator()(argument_type const & resp)
-    {
-        //double resp = leftCornerResponse(x,y);
-	if (resp > minResponse) {
-	    // add to point map
-	    points.insert(make_pair(resp,Diff2D(x,y)));
-	    // if we have reached the maximum
-	    // number of points, increase the threshold, to avoid
-	    // growing the points map too much.
-	    // extract more than nPoints, because some might be bad
-	    // and cannot be matched with the other image.
-	    if (points.size() > 5*nPoints) {
-		// remove the point with the lowest corner response.
-		leftCorners(points.begin()->second.x,points.begin()->second.y)=0;
-		points.erase(points.begin());
-		// use new threshold for next selection.
-		minResponse = points.begin()->first;
-	    }
-	}
-    }
-
-    argument_type minResponse;
-    std::multimap<argument_type, vigra::Diff2D> points;
-    int nPoints;
-}
-
-#endif
-
 template <class ImageType>
-void createCtrlPoints(Panorama & pano, int img1, const ImageType & leftImg, const ImageType & leftImgOrig, int img2, const ImageType & rightImg, const ImageType & rightImgOrig, int pyrLevel, double scale, unsigned nPoints, unsigned grid, bool stereo = false)
+void createCtrlPoints(Panorama & pano, int img1, const ImageType & leftImg, const ImageType & leftImgOrig, int img2, const ImageType & rightImg, const ImageType & rightImgOrig, int pyrLevel, double scale, unsigned nPoints, unsigned grid, double corrThresh=0.9, bool stereo = false)
 {
     typedef typename ImageType::value_type VT;
     //////////////////////////////////////////////////
@@ -222,8 +176,6 @@ void createCtrlPoints(Panorama & pano, int img1, const ImageType & leftImg, cons
             long templWidth = 20;
             long sWidth = 100;
             long sWidth2 = scaleFactor;
-            double corrThresh = 0.9;
-            //double curvThresh = 0.0;
 
             vigra_ext::CorrelationResult res;
 
@@ -390,6 +342,7 @@ struct Parameters
     Parameters()
     {
         cpErrorThreshold = 3;
+        corrThresh = 0.9;
         nPoints = 8;
         grid = 5;
         hfov = 0;
@@ -406,9 +359,11 @@ struct Parameters
         pop_out = false;
         crop = false;
         fisheye = false;
+        gpu = false;
     }
 
     double cpErrorThreshold;
+    double corrThresh;
     int nPoints;
     int grid;		// Partition images into grid x grid subregions, each with npoints
     double hfov;
@@ -424,6 +379,7 @@ struct Parameters
     bool stereo_window;
     bool pop_out;
     bool crop;
+    bool gpu;
     int pyrLevel;
     std::string alignedPrefix;
     std::string ptoFile;
@@ -431,46 +387,35 @@ struct Parameters
     string basename;
 };
 
+struct SortImageVectorEV
+{
+public:
+    SortImageVectorEV(const Panorama* pano) : m_pano(pano) {};
+    bool operator()(const unsigned int i, const unsigned int j)
+    {
+        return m_pano->getImage(i).getExposureValue() > m_pano->getImage(j).getExposureValue();
+    };
+private:
+    const Panorama* m_pano;
+};
+
 template <class PixelType>
 int main2(std::vector<std::string> files, Parameters param)
 {
     typedef vigra::BasicImage<PixelType> ImageType;
     try {
-        // load first image
-        vigra::ImageImportInfo firstImgInfo(files[0].c_str());
-
-        // original size
-        ImageType * leftImgOrig = new ImageType(firstImgInfo.size());
-        // rescale image
-        ImageType * leftImg = new ImageType();
-        {
-            if(firstImgInfo.numExtraBands() == 1) {
-                vigra::BImage alpha(firstImgInfo.size());
-                vigra::importImageAlpha(firstImgInfo, destImage(*leftImgOrig), destImage(alpha));
-            } else if (firstImgInfo.numExtraBands() == 0) {
-                vigra::importImage(firstImgInfo, destImage(*leftImgOrig));
-            } else {
-                vigra_fail("Images with multiple extra (alpha) channels not supported");
-            }
-            reduceNTimes(*leftImgOrig, *leftImg, param.pyrLevel);
-        }
-
-
         Panorama pano;
         Lens l;
 
         // add the first image.to the panorama object
-        // default settings
-        double focalLength = 50;
-        double cropFactor = 0;
-        
         SrcPanoImage srcImg;
         srcImg.setFilename(files[0]);
         
         if (param.fisheye) {
             srcImg.setProjection(SrcPanoImage::FULL_FRAME_FISHEYE);
         }
-        srcImg.readEXIF(focalLength, cropFactor, true, true);
+        srcImg.readEXIF();
+        srcImg.applyEXIFValues();
         // disable autorotate
         srcImg.setRoll(0);
         if (srcImg.getSize().x == 0 || srcImg.getSize().y == 0) {
@@ -481,7 +426,7 @@ int main2(std::vector<std::string> files, Parameters param)
         // use hfov specified by user.
         if (param.hfov > 0) {
             srcImg.setHFOV(param.hfov);
-        } else if (cropFactor == 0) {
+        } else if (srcImg.getCropFactor() == 0) {
             // could not read HFOV, assuming default: 50
             srcImg.setHFOV(50);
         }
@@ -504,15 +449,9 @@ int main2(std::vector<std::string> files, Parameters param)
             opts.setProjection(PanoramaOptions::RECTILINEAR);
         }
         opts.setHFOV(srcImg.getHFOV(), false);
-
-        if (srcImg.getRoll() == 0.0 || srcImg.getRoll() == 180.0) {
-            opts.setWidth(srcImg.getSize().x, false);
-            opts.setHeight(srcImg.getSize().y);
-        } else {
-            opts.setWidth(srcImg.getSize().y, false);
-            opts.setHeight(srcImg.getSize().x);
-        }
-            // output to tiff format
+        opts.setWidth(srcImg.getSize().x, false);
+        opts.setHeight(srcImg.getSize().y);
+        // output to tiff format
         opts.outputFormat = PanoramaOptions::TIFF_m;
         opts.tiff_saveROI = false;
         // m estimator, to be more robust against points on moving objects
@@ -522,26 +461,24 @@ int main2(std::vector<std::string> files, Parameters param)
         // variables that should be optimized
         // optimize nothing in the first image
         OptimizeVector optvars(1);
+        std::vector<unsigned int> images;
+        images.push_back(0);
 
-        ImageType * rightImg = new ImageType(leftImg->size());
-        ImageType * rightImgOrig = new ImageType(leftImgOrig->size());
         StandardImageVariableGroups variable_groups(pano);
 
-        // loop to add images and control points between them.
+        // loop to add images.
         for (int i = 1; i < (int) files.size(); i++) {
-            if (g_verbose > 0) {
-                cout << "Creating control points between " << files[i-1] << " and " << files[i] << std::endl;
-            }
             // add next image.
             srcImg.setFilename(files[i]);
-            srcImg.readEXIF(focalLength, cropFactor, true, true);
+            srcImg.readEXIF();
+            srcImg.applyEXIFValues();
             if (srcImg.getSize().x == 0 || srcImg.getSize().y == 0) {
                 cerr << "Could not decode image: " << files[i] << "Unsupported image file format";
                 return 1;
             }
             if (param.hfov > 0) {
                 srcImg.setHFOV(param.hfov);
-            } else if (cropFactor == 0) {
+            } else if (srcImg.getCropFactor() == 0) {
                 // could not read HFOV, assuming default: 50
                 srcImg.setHFOV(50);
             }
@@ -560,38 +497,13 @@ int main2(std::vector<std::string> files, Parameters param)
             if (param.optCenter) {
                 pano.unlinkImageVariableRadialDistortionCenterShift(0);
             }
-            
             // All images are in the same stack: Link the stack variable.
             pano.linkImageVariableStack(imgNr, 0);
-            
-            // load the actual image data of the next image
-            vigra::ImageImportInfo nextImgInfo(files[i].c_str());
-            assert(nextImgInfo.size() == firstImgInfo.size());
-            {
-                if (nextImgInfo.numExtraBands() == 1) {
-                    vigra::BImage alpha(nextImgInfo.size());
-                    vigra::importImageAlpha(nextImgInfo, destImage(*rightImgOrig), destImage(alpha));
-                } else if (nextImgInfo.numExtraBands() == 0) {
-                    vigra::importImage(nextImgInfo, destImage(*rightImgOrig));
-                } else {
-                    vigra_fail("Images with multiple extra (alpha) channels not supported");
-                }
-                reduceNTimes(*rightImgOrig, *rightImg, param.pyrLevel);
-            }
-
-            // add control points.
-            // work on smaller images
-            // TODO: or use a fast interest point operator.
-            createCtrlPoints(pano, i-1, *leftImg, *leftImgOrig, i, *rightImg, *rightImgOrig, param.pyrLevel, 2, param.nPoints, param.grid, param.stereo);
-
-            // swap images;
-            delete leftImg;
-            delete leftImgOrig;
-            leftImg = rightImg;
-            leftImgOrig = rightImgOrig;
-            rightImg = new ImageType(leftImg->size());
-            rightImgOrig = new ImageType(leftImgOrig->size());
-
+            // exposure value is linked, reset to value found in EXIF
+            pano.unlinkImageVariableExposureValue(0);
+            srcImg.setExposureValue(srcImg.calcExifExposureValue());
+            pano.setSrcImage(i, srcImg);
+            images.push_back(i);
             // optimize yaw, roll, pitch
             std::set<std::string> vars;
             vars.insert("y");
@@ -619,6 +531,68 @@ int main2(std::vector<std::string> files, Parameters param)
                 vars.insert("TrZ");
             }
             optvars.push_back(vars);
+
+        };
+            
+        // sort now all images by exposure value
+        std::sort(images.begin(), images.end(), SortImageVectorEV(&pano));
+
+        // load first image
+        vigra::ImageImportInfo firstImgInfo(pano.getSrcImage(images[0]).getFilename().c_str());
+
+        // original size
+        ImageType * leftImgOrig = new ImageType(firstImgInfo.size());
+        // rescale image
+        ImageType * leftImg = new ImageType();
+        {
+            if(firstImgInfo.numExtraBands() == 1) {
+                vigra::BImage alpha(firstImgInfo.size());
+                vigra::importImageAlpha(firstImgInfo, destImage(*leftImgOrig), destImage(alpha));
+            } else if (firstImgInfo.numExtraBands() == 0) {
+                vigra::importImage(firstImgInfo, destImage(*leftImgOrig));
+            } else {
+                vigra_fail("Images with multiple extra (alpha) channels not supported");
+            }
+            reduceNTimes(*leftImgOrig, *leftImg, param.pyrLevel);
+        }
+
+
+        ImageType * rightImg = new ImageType(leftImg->size());
+        ImageType * rightImgOrig = new ImageType(leftImgOrig->size());
+        // loop to add control points between them.
+        for (int i = 1; i < (int) images.size(); i++) {
+            if (g_verbose > 0) {
+                cout << "Creating control points between " << pano.getSrcImage(images[i-1]).getFilename().c_str() << " and " << 
+                    pano.getSrcImage(images[i]).getFilename().c_str() << std::endl;
+            }
+
+            // load the actual image data of the next image
+            vigra::ImageImportInfo nextImgInfo(pano.getSrcImage(images[i]).getFilename().c_str());
+            assert(nextImgInfo.size() == firstImgInfo.size());
+            {
+                if (nextImgInfo.numExtraBands() == 1) {
+                    vigra::BImage alpha(nextImgInfo.size());
+                    vigra::importImageAlpha(nextImgInfo, destImage(*rightImgOrig), destImage(alpha));
+                } else if (nextImgInfo.numExtraBands() == 0) {
+                    vigra::importImage(nextImgInfo, destImage(*rightImgOrig));
+                } else {
+                    vigra_fail("Images with multiple extra (alpha) channels not supported");
+                }
+                reduceNTimes(*rightImgOrig, *rightImg, param.pyrLevel);
+            }
+
+            // add control points.
+            // work on smaller images
+            // TODO: or use a fast interest point operator.
+            createCtrlPoints(pano, images[i-1], *leftImg, *leftImgOrig, images[i], *rightImg, *rightImgOrig, param.pyrLevel, 2, param.nPoints, param.grid, param.corrThresh, param.stereo);
+
+            // swap images;
+            delete leftImg;
+            delete leftImgOrig;
+            leftImg = rightImg;
+            leftImgOrig = rightImgOrig;
+            rightImg = new ImageType(leftImg->size());
+            rightImgOrig = new ImageType(leftImgOrig->size());
         }
         delete leftImg;
         delete rightImg;
@@ -627,8 +601,7 @@ int main2(std::vector<std::string> files, Parameters param)
 
         // optimize everything.
         pano.setOptimizeVector(optvars);
-        bool optimizeError = false;
-        optimizeError = (PTools::optimize(pano) > 0);
+        bool optimizeError = (PTools::optimize(pano) > 0);
 
         // need to do some basic outlier pruning.
         // remove all points with error higher than a specified threshold
@@ -653,8 +626,6 @@ int main2(std::vector<std::string> files, Parameters param)
         if (param.crop) autoCrop(pano);
 
         UIntSet imgs = pano.getActiveImages();
-
-
         if (optimizeError)
         {
             if (param.ptoFile.size() > 0) {
@@ -682,9 +653,18 @@ int main2(std::vector<std::string> files, Parameters param)
             pano.setOptions(opts);
 
             // remap all images
-            StreamMultiProgressDisplay progress(cout);
+            MultiProgressDisplay* progress;
+            if(g_verbose > 0)
+            {
+                progress = new StreamMultiProgressDisplay(cout);
+            }
+            else
+            {
+                progress = new DummyMultiProgressDisplay();
+            };
             stitchPanorama(pano, pano.getOptions(),
-                           progress, opts.outfile, imgs);
+                           *progress, opts.outfile, imgs);
+            delete progress;
         }
         if (param.alignedPrefix.size()) {
             // disable all exposure compensation stuff.
@@ -694,6 +674,7 @@ int main2(std::vector<std::string> files, Parameters param)
             opts.outputFormat = PanoramaOptions::TIFF_m;
             opts.outputPixelType = "";
             opts.outfile = param.alignedPrefix;
+            opts.remapUsingGPU = param.gpu;
             pano.setOptions(opts);
             for (unsigned i=0; i < pano.getNrOfImages(); i++) {
                 SrcPanoImage img = pano.getSrcImage(i);
@@ -701,9 +682,18 @@ int main2(std::vector<std::string> files, Parameters param)
                 pano.setSrcImage(i, img);
             }
             // remap all images
-            StreamMultiProgressDisplay progress(cout);
+            MultiProgressDisplay* progress;
+            if(g_verbose > 0)
+            {
+                progress = new StreamMultiProgressDisplay(cout);
+            }
+            else
+            {
+                progress = new DummyMultiProgressDisplay();
+            };
             stitchPanorama(pano, pano.getOptions(),
-                           progress, opts.outfile, imgs);
+                           *progress, opts.outfile, imgs);
+            delete progress;
 
         }
 
@@ -732,40 +722,56 @@ int main(int argc, char *argv[])
     g_verbose = 0;
 
     Parameters param;
-//    // use to override exposure value on the command line?
-//    std::map<std::string, double> exposureValueMap;
-    while ((c = getopt (argc, argv, optstring)) != -1)
+    enum
+    {
+        CORRTHRESH=1000,
+        THREADS,
+        GPU,
+    };
+
+    static struct option longOptions[] =
+    {
+        {"corr", required_argument, NULL, CORRTHRESH },
+        {"threads", required_argument, NULL, THREADS },
+        {"gpu", no_argument, NULL, GPU },
+        {"help", no_argument, NULL, 'h' },
+        0
+    };
+    int optionIndex = 0;
+    int nThread = getCPUCount();
+    if (nThread < 0) nThread = 1;
+    while ((c = getopt_long (argc, argv, optstring, longOptions,&optionIndex)) != -1)
         switch (c) {
         case 'a':
             param.alignedPrefix = optarg;
             break;
         case 'c':
             param.nPoints = atoi(optarg);
-	    if (param.nPoints<1) {
-		cerr << "Invalid parameter: Number of points/grid (-c) must be at least 1" << std::endl;
-		return 1;
-	    }
+            if (param.nPoints<1) {
+                cerr << "Invalid parameter: Number of points/grid (-c) must be at least 1" << std::endl;
+                return 1;
+            }
             break;
         case 'e':
             param.fisheye = true;
             break;
         case 'f':
             param.hfov = atof(optarg);
-	    if (param.hfov<=0) {
-		cerr << "Invalid parameter: HFOV (-f) must be greater than 0" << std::endl;
-		return 1;
-	    }
+            if (param.hfov<=0) {
+                cerr << "Invalid parameter: HFOV (-f) must be greater than 0" << std::endl;
+                return 1;
+            }
+            break;
+        case 'g':
+            param.grid = atoi(optarg);
+            if (param.grid <1 || param.grid>50) {
+                cerr << "Invalid parameter: number of grid cells (-g) should be between 1 and 50" << std::endl;
+                return 1;
+            }
+            break;
+        case 'l':
+            param.linear = true;
             break;
-	case 'g':
-	    param.grid = atoi(optarg);
-	    if (param.grid <1 || param.grid>50) {
-		cerr << "Invalid parameter: number of grid cells (-g) should be between 1 and 50" << std::endl;
-		return 1;
-	    }
-	    break;
-	case 'l':
-	    param.linear = true;
-	    break;
         case 'm':
             param.optHFOV = true;
             break;
@@ -801,10 +807,10 @@ int main(int argc, char *argv[])
             break;
         case 't':
             param.cpErrorThreshold = atof(optarg);
-	    if (param.cpErrorThreshold <= 0) {
-		cerr << "Invalid parameter: control point error threshold (-t) must be greater than 0" << std::endl;
-		return 1;
-	    }
+            if (param.cpErrorThreshold <= 0) {
+                cerr << "Invalid parameter: control point error threshold (-t) must be greater than 0" << std::endl;
+                return 1;
+            }
             break;
         case 'p':
             param.ptoFile = optarg;
@@ -818,13 +824,27 @@ int main(int argc, char *argv[])
         case 'h':
             usage(argv[0]);
             return 0;
-	case 's':
-	    param.pyrLevel = atoi(optarg);
-	    if (param.pyrLevel<0 || param.pyrLevel >8) {
-		cerr << "Invalid parameter: scaling (-s) should be between 0 and 8" << std::endl;
-		return 1;
-	    }
-	    break;
+        case 's':
+            param.pyrLevel = atoi(optarg);
+            if (param.pyrLevel<0 || param.pyrLevel >8) {
+            cerr << "Invalid parameter: scaling (-s) should be between 0 and 8" << std::endl;
+            return 1;
+            }
+            break;
+        case CORRTHRESH:
+            param.corrThresh = atoi(optarg);
+            if(param.corrThresh<=0 || param.corrThresh>1.0)
+            {
+                cerr << "Invalid correlation value. Should be between 0 and 1" << endl;
+                return 1;
+            };
+            break;
+        case THREADS:
+            nThread = atoi(optarg);
+            break;
+        case GPU:
+            param.gpu = true;
+            break;
         default:
             cerr << "Invalid parameter: " << optarg << std::endl;
             usage(argv[0]);
@@ -851,7 +871,8 @@ int main(int argc, char *argv[])
     for (size_t i=0; i < nFiles; i++)
         files.push_back(argv[optind+i]);
 
-    // TODO: sort images in pano by exposure
+    if (nThread == 0) nThread = 1;
+    vigra_ext::ThreadManager::get().setNThreads(nThread);
 
     std::string pixelType;
 
@@ -863,6 +884,10 @@ int main(int argc, char *argv[])
         return 1;
     }
 
+    if(param.gpu)
+    {
+        param.gpu=hugin_utils::initGPU(&argc, argv);
+    };
     if (pixelType == "UINT8") {
         return main2<RGBValue<UInt8> >(files, param);
     } else if (pixelType == "INT16") {
@@ -873,8 +898,16 @@ int main(int argc, char *argv[])
         return main2<RGBValue<float> >(files, param);
     } else {
         cerr << " ERROR: unsupported pixel type: " << pixelType << std::endl;
+        if(param.gpu)
+        {
+            hugin_utils::wrapupGPU();
+        };
         return 1;
     }
 
+    if(param.gpu)
+    {
+        hugin_utils::wrapupGPU();
+    };
     return 0;
 }
