@@ -808,11 +808,11 @@ int processImg(const char *filename)
         else
           red_name=std::string("red_")+filename;
 
-        SrcPanoImage srcRedImg(filename);
+        SrcPanoImage srcRedImg;
         srcRedImg.setSize(imgInfo.size());
         srcRedImg.setProjection(SrcPanoImage::RECTILINEAR);
         srcRedImg.setHFOV(10);
-        srcRedImg.setExifCropFactor(1);
+        srcRedImg.setCropFactor(1);
         srcRedImg.setFilename(red_name);
         int imgRedNr = pano.addImage(srcRedImg);
         lenses.updatePartNumbers();
@@ -825,11 +825,11 @@ int processImg(const char *filename)
         else
           green_name=std::string("green_")+filename;
 
-        SrcPanoImage srcGreenImg( filename);
+        SrcPanoImage srcGreenImg;
         srcGreenImg.setSize(imgInfo.size());
         srcGreenImg.setProjection(SrcPanoImage::RECTILINEAR);
         srcGreenImg.setHFOV(10);
-        srcGreenImg.setExifCropFactor(1);
+        srcGreenImg.setCropFactor(1);
         srcGreenImg.setFilename(green_name);
         int imgGreenNr = pano.addImage(srcGreenImg);
         lenses.updatePartNumbers();
@@ -842,11 +842,11 @@ int processImg(const char *filename)
         else
           blue_name=std::string("blue_")+filename;
 
-        SrcPanoImage srcBlueImg( filename);
+        SrcPanoImage srcBlueImg;
         srcBlueImg.setSize(imgInfo.size());
         srcBlueImg.setProjection(SrcPanoImage::RECTILINEAR);
         srcBlueImg.setHFOV(10);
-        srcBlueImg.setExifCropFactor(1);
+        srcBlueImg.setCropFactor(1);
         srcBlueImg.setFilename(blue_name);
         int imgBlueNr = pano.addImage(srcBlueImg);
         lenses.updatePartNumbers();
